<div class="overlay" id="import-project-overlay"
    data-title="Import existing project"
    data-placement="left auto">

    If you have already created and exported a project in
    RDMO and would like to add it to your project list,
    you can import an existing project here.

    {% include 'overlays/buttons.html'%}
</div>
