# Generated by Django 2.2.13 on 2020-09-23 13:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0024_related_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='optionset',
            name='provider_key',
            field=models.SlugField(blank=True, help_text='The provider for this optionset. If set, it will create dynamic options for this optionset.', max_length=128, verbose_name='Provider'),
        ),
    ]
