# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-01 08:33
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0015_permissions'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='catalog',
            field=models.ForeignKey(help_text='The catalog which will be used for this project.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='questions.Catalog', verbose_name='Catalog'),
        ),
    ]
