<div class="overlay" id="export-project-overlay"
    data-title="Export"
    data-placement="left auto">

    You can export your project here if you want to import it into RDMO at a later date or to another RDMO instance.

    {% include 'overlays/buttons.html'%}
</div>
