# Generated by Django 2.2.24 on 2021-07-23 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0063_questionset_questionset'),
    ]

    operations = [
        migrations.AlterField(
            model_name='question',
            name='widget_type',
            field=models.CharField(help_text='Type of widget for this question.', max_length=16, verbose_name='Widget type'),
        ),
    ]
