{% load i18n %}
{% load rules %}
{% load mptt_tags %}
{% load accounts_tags %}

{% has_perm 'projects.change_project_object' request.user project as can_change_project %}

<div class="project-header">
    <h1>{{ project.title }}</h1>

    <table class="table">
        <tbody>
            <tr>
                <td style="width: 20%;">
                    <strong>{% trans 'Description' %}</strong>
                </td>
                <td>
                    {% include 'projects/project_detail_header_description.html' %}
                </td>
            </tr>
            <tr id="project-catalog">
                <td>
                    <strong>{% trans 'Catalog' %}</strong>
                </td>
                <td>
                    {% include 'projects/project_detail_header_catalog.html' %}
                </td>
            </tr>
            {% if project.is_child_node or project.get_descendant_count %}
            {% drilldown_tree_for_node project as project_tree all_descendants %}
            <tr>
                <td>
                    <strong>{% trans 'Project hierarchy' %}</strong>
                </td>
                <td>
                    {% include 'projects/project_detail_header_hierarchy.html' %}
                </td>
            </tr>
            {% endif %}
        </tbody>
    </table>
</div>
