# Generated by Django 2.2.7 on 2019-11-05 14:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('views', '0021_view_catalogs'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='view',
            managers=[
            ],
        ),
    ]
