<div class="overlay" id="project-views-overlay"
    data-title="Vues"
    data-placement="bottom auto">

    Les vues sont des modèles de formulaires/documents. Les vues sont automatiquement remplies sur la base des réponses données dans le questionnaire et peuvent ensuite être exportées et envoyées dans différents formats. Au départ, toutes les vues sont vides. Pour que les modèles soient complètement remplis, il faut répondre à toutes les questions pertinentes. Les réponses qui sont utilisées dans plusieurs modèles sont automatiquement transférées à tous les catalogues de questions et à toutes les vues.

    {% include 'overlays/buttons.html'%}
</div>
