# Generated by Django 2.2.2 on 2019-07-01 16:00

from django.db import migrations
import django.db.models.manager
import rdmo.questions.managers


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0046_catalog_groups'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='catalog',
            managers=[
                ('objects', django.db.models.manager.Manager()),
                ('on_site', rdmo.questions.managers.CatalogManager()),
            ],
        ),
    ]
