# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-10 16:04
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0034_remove_attributeentity_conditions'),
        ('questions', '0022_data_migration')
    ]

    operations = [
        migrations.RemoveField(
            model_name='attributeentity',
            name='is_collection',
        ),
        migrations.RemoveField(
            model_name='attributeentity',
            name='parent_collection',
        ),
    ]
