{% load i18n %}

    <p class="text-muted">
        {% blocktrans trimmed %}
        Here you can see who can access the project and invite additional members. You can use the user roles to manage which rights the benefits have. Unless you are the last owner, you can leave the project with the button next to your name.
        {% endblocktrans %}
    </p>
