{% load static %}
{% load core_tags %}
{% load i18n %}

<div class="text-center">
    <img class="rdmo-logo" src="{% static 'core/img/rdmo-logo.svg' %}" alt="{% trans 'RDMO Logo' %}" />

    <h1>Research data management organiser</h1>

    <h4>Version {% version %}</h4>
</div>

<div class="text-justify">
    <p>
        The Research Data Management Organiser (RDMO) enables institutions as well as researchers to plan and carry out their management of research data. RDMO can assemble all relevant planning information and data management tasks across the whole life cycle of the research data.
    </p>

    <p>
        RDMO is ready for application in smaller or bigger projects. In the next projectphase, which started November 2017, the RDMO tool will be extended and the project partners AIP, FHP, and KIT Library will collaborate with the RDMO users to improve its usage. The tool will be extended by enhancing its implementation of roles and interfaces to institutional infrastructure, e.g. repositories, ticketing systems, and the infrastructure for authentication and autorization. Tutorials, documentation and other material are planned for dissemination, and workshops for users and developers.
    </p>

    <p>
        More Information about RDMO is available on <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
    </p>
</div>
