# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-03 13:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0011_path'),
    ]

    operations = [
        migrations.AlterField(
            model_name='questionentity',
            name='path',
            field=models.CharField(blank=True, help_text='The path part of the URI of this question/questionset (auto-generated).', max_length=512, null=True, verbose_name='Path'),
        ),
        migrations.AlterField(
            model_name='section',
            name='path',
            field=models.CharField(blank=True, help_text='The path part of the URI of this section (auto-generated).', max_length=512, null=True, verbose_name='Label'),
        ),
        migrations.AlterField(
            model_name='subsection',
            name='path',
            field=models.CharField(blank=True, help_text='The path part of the URI of this subsection (auto-generated).', max_length=512, null=True, verbose_name='Label'),
        ),
    ]
