# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-10 12:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0020_data_migration'),
    ]

    operations = [
        migrations.AddField(
            model_name='questionentity',
            name='is_collection',
            field=models.BooleanField(default=False, help_text='Designates whether this question/questionset is a collection.', verbose_name='is collection'),
        ),
    ]
