{% extends 'core/page.html' %}
{% load i18n %}
{% load core_tags %}

{% block page %}

{% if object %}

    <h1>{% trans 'Update snapshot' %}</h1>

    {% bootstrap_form submit=_('Update snapshot') %}

{% else %}

    <h1>{% trans 'Create new snapshot' %}</h1>

    {% bootstrap_form submit=_('Create snapshot') %}

{% endif %}

{% endblock %}
