<h2>Welcome to RDMO</h2>

<p>
    The aim of the RDMO project is to deliver a web application to assist structured planning, implementation and administration of the data in a scientific project. Additionally, the gathered information can be cast into textual forms suitable for funding agencies requirements or for reports.
</p>

<p>
    This is a prototype of the software, for demonstration purposes.
</p>

<p>
    For more information about the project visit <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
</p>
