{% extends 'core/page.html' %}
{% load i18n %}
{% load core_tags %}

{% block head %}
<script>
    $(document).ready(function() {
        $('[data-toggle="tooltip"]').tooltip();
    });
</script>
{% endblock %}

{% block page %}

{% if object %}

    {% if form.fields.catalogs %}

        <h1>{% trans 'Update project catalog' %}</h1>

    {% elif form.fields.tasks %}

        <h1>{% trans 'Update project tasks' %}</h1>

        <p class="help-block">{% trans 'Please note that their status is lost when you remove tasks from the project.' %}</p>

        {% bootstrap_form submit=_('Save tasks') %}

    {% elif form.fields.views %}

        <h1>{% trans 'Update project views' %}</h1>
        {% bootstrap_form submit=_('Save views') %}

    {% else %}

        <h1>{% trans 'Update project information' %}</h1>
        {% bootstrap_form submit=_('Save project') %}

    {% endif %}

{% else %}

    <h1>{% trans 'Create new project' %}</h1>

    {% bootstrap_form submit=_('Create project') %}

{% endif %}

{% endblock %}
