<div class="overlay" id="project-snapshots-overlay"
    data-title="Instantanés"
    data-placement="top auto">

    Les instantanés vous permettent de sauvegarder toutes les réponses à un moment donné et de geler une certaine étape du projet. Plus tard, l'instantané peut être utilisé pour créer des vues et le projet peut également être réinitialisé à un instantané précédent si nécessaire.

    {% include 'overlays/buttons.html'%}
</div>
