{% load i18n %}

    <div class="form-group" ng-if="question.widget_type === 'select'">
        {% include 'projects/project_questions_question_label.html' %}
        {% include 'projects/project_questions_question_help.html' %}
        {% include 'projects/project_questions_question_warning.html' %}

        <div ng-if="question.is_collection">
            {% include 'projects/project_questions_add_field_help.html' %}
        </div>

        <div ng-repeat="value in service.values[question.attribute][valueset.set_prefix][valueset.set_index] track by $index">
            <div class="collection" ng-hide="value.removed">
                <div class="options">
                    {% include 'projects/project_questions_default.html' %}
                    {% include 'projects/project_questions_remove_field.html' %}
                </div>

                <select class="form-control"
                    ng-attr-id="id_{$ question.attribute $}_{$ valueset.set_prefix $}_{$ valueset.set_index $}_{$ $index $}"
                    ng-model="value.selected"
                    ng-disabled="service.project.read_only"
                    ng-change="service.changed(value, true)"
                    ng-class="{'default-value': service.isDefaultValue(question, value)}">
                    <option value="">--- {% trans 'Please select' %} ---</option>
                    <option ng-repeat="option in question.options" ng-hide="valueset.hidden.optionsets[option.optionset]" value="{$ option.id $}">
                        {$ option.text $}
                    </option>
                </select>
            </div>
        </div>

        <div ng-if="question.is_collection">
            {% include 'projects/project_questions_add_field_button.html' %}
        </div>
    </div>
