{% extends 'core/page.html' %}
{% load i18n %}
{% load core_tags %}

{% block page %}

    <h1>{% trans "Leave project" %}</h1>

    <p>
        {% blocktrans trimmed %}
        You are about to leave the project <strong>{{ object }}</strong>.
        {% endblocktrans %}
    </p>

    <p>
        {% trans 'If you want to access this project again, somebody will need to invite you!' %}
    </p>

    {% bootstrap_form submit=_('Leave project') %}

{% endblock %}
