{% load i18n %}

    <form method="post" action="{{ action }}" novalidate>
        {% csrf_token %}
        <input type="hidden" name="next" value="{{ next }}" />

        {% include 'core/bootstrap_form_fields.html' %}

        <input type="submit" value="{{ submit }}" class="btn btn-primary" />
        <input type="submit" name="cancel" value="{% trans 'Cancel' %}" class="btn" />
    </form>
