<div class="overlay" id="create-project-overlay"
    data-title="Crea nuovo progetto "
    data-placement="left auto">

    Come primo passo puoi creare un nuovo progetto usando questo link.

    {% include 'overlays/buttons.html'%}
</div>
