{% extends 'core/page.html' %}
{% load i18n %}
{% load account %}
{% load socialaccount %}
{% load core_tags %}

{% block page %}

<h1>{% trans "Login Cancelled" %}</h1>

{% url 'account_login' as login_url %}

<p>
    {% blocktrans %}You decided to cancel logging in to our site using one of your existing accounts. If this was a mistake, please proceed to <a href="{{login_url}}">sign in</a>.{% endblocktrans %}
</p>

{% endblock %}
