<div class="overlay" id="project-snapshots-overlay"
    data-title="Istantanee"
    data-placement="top auto">

    Le istantanee permettono di salvare tutte le risposte ad un certo punto nel tempo e congelare una certa fase del progetto. Più tardi, l'istantanea può essere usata per creare delle viste e il progetto può anche essere riportato a un'istantanea precedente, se necessario.

    {% include 'overlays/buttons.html'%}
</div>
