# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-09-23 14:24
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0007_ordering'),
    ]

    operations = [
        migrations.AlterField(
            model_name='condition',
            name='title',
            field=models.CharField(max_length=256, validators=[django.core.validators.RegexValidator('^[a-zA-z0-9_]*$', 'Only letters, numbers, or underscores are allowed.')]),
        ),
    ]
