<div class="overlay" id="create-project-overlay"
    data-title="Créer un nouveau projet "
    data-placement="left auto">

    Dans un premier temps, vous pouvez créer un nouveau projet en utilisant ce lien.

    {% include 'overlays/buttons.html'%}
</div>
