# Generated by Django 2.2.18 on 2021-05-20 15:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0060_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='width',
            field=models.IntegerField(blank=True, help_text='Width for the widget of this question (optional, full with: 12).', null=True, verbose_name='Width'),
        ),
    ]
