<div class="overlay" id="export-project-overlay"
    data-title="Export"
    data-placement="left auto">

    Sie können Ihr Projekt hier exportieren, falls Sie es zu einem späteren Zeitpunkt in RDMO importieren möchten oder zu einer anderen RDMO Instanz mitnehmen möchten.

    {% include 'overlays/buttons.html'%}
</div>
