# Generated by Django 2.2.6 on 2019-10-11 12:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0028_meta'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='project',
            managers=[
            ],
        ),
    ]
