<div class="row">
    <div class="footer-col col-md-4">
        <h4>Informazioni su RDMO</h4>
        <p>
            RDMO supporta la pianificazione sistematica, l'organizzazione e l'implementazione della gestione dei dati nel corso di un progetto di ricerca.
        </p>
        <p>
            RDMO è un software open source e disponibile su <a href="https://github.com/rdmorganiser/rdmo">https://github.com/rdmorganiser/rdmo</a>
        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Contatta</h4>
        <p>

        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Impronta e protezione dei dati</h4>
        <p>

        </p>
    </div>
</div>
