# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-27 15:28
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('views', '0002_view_template'),
    ]

    operations = [
        migrations.RenameField(
            model_name='view',
            old_name='description',
            new_name='comment',
        ),
        migrations.RenameField(
            model_name='view',
            old_name='title',
            new_name='key',
        ),
    ]
