<div class="overlay" id="issue-attachments-overlay"
    data-title="Ansichten"
    data-placement="left auto">

    Hier können Sie eine passende Ansicht im gewünschten Format an Ihre Nachricht anhängen.

    {% include 'overlays/buttons.html'%}
</div>
