<div class="overlay" id="project-snapshots-overlay"
    data-title="Snapshots"
    data-placement="top auto">

    Snapshots allow you to save all answers at a certain point in time and freeze a certain stage of the project. Later, the snapshot can be used to create views and the project can also be reset to a previous snapshot if needed.

    {% include 'overlays/buttons.html'%}
</div>
