<div class="overlay" id="project-issues-overlay"
    data-title="Attività"
    data-placement="bottom auto">

    I compiti sono generati automaticamente dalle risposte che dai nei questionari. Nella pagina di ogni compito puoi vedere quali delle tue risposte portano all'attivazione del compito. Puoi anche cambiare lo stato dei tuoi compiti con l'icona della matita quando hai iniziato o finito un compito. Con l'icona dell'aeroplano di carta puoi inviare una e-mail e allegare una vista nel formato desiderato, se necessario. All'inizio, la panoramica dei compiti è vuota.

    {% include 'overlays/buttons.html'%}
</div>
