<h2>Willkommen bei RDMO</h2>

<p>
    Das Ziel des RDMO Projekts ist es, eine Webapplikation bereitzustellen, die die strukturierte Planung, Umsetzung und Verwaltung der Daten in einem wissenschaftlichen Projekt unterstützt. Zusätzlich sollen die gesammelten Informationen in textueller Form für Anforderungen von Förderern oder für Berichte ausgebbar sein.
</p>

<p>
    Diese Webseite ist ein Prototyp zur Veranschaulichung der bereits implementierten Funktionen.
</p>

<p>
    Wenn Sie mehr über das Projekt erfahren wollen, besuchen Sie <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
</p>
