# Generated by Django 2.2.18 on 2021-05-31 11:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0049_invite'),
    ]

    operations = [
        migrations.AddField(
            model_name='value',
            name='set_prefix',
            field=models.CharField(blank=True, default='', help_text='The position of this value with respect to superior sets (i.e. for nested question sets).', max_length=16, verbose_name='Set prefix'),
        ),
        migrations.AlterField(
            model_name='value',
            name='collection_index',
            field=models.IntegerField(default=0, help_text='The position of this value in a list (i.e. for a question tagged as collection).', verbose_name='Collection index'),
        ),
        migrations.AlterField(
            model_name='value',
            name='set_index',
            field=models.IntegerField(default=0, help_text='The position of this value in a set (i.e. for a question set tagged as collection).', verbose_name='Set index'),
        ),
    ]
