<div class="overlay" id="issue-attachments-overlay"
    data-title="Views"
    data-placement="left auto">

    Here you can attach a suitable view in the desired format to your message.

    {% include 'overlays/buttons.html'%}
</div>
