<div class="overlay" id="export-project-overlay"
    data-title="Esporta"
    data-placement="left auto">

    Puoi esportare qui il tuo progetto se vuoi importarlo in RDMO in una data successiva o in un'altra istanza di RDMO.

    {% include 'overlays/buttons.html'%}
</div>
