# Generated by Django 2.2.13 on 2020-10-02 16:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0041_value_external_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='site',
            field=models.ForeignKey(help_text='The site this project belongs to (in a multi site setup).', null=True, on_delete=django.db.models.deletion.SET_NULL, to='sites.Site', verbose_name='Site'),
        ),
    ]
