<div class="overlay" id="create-project-overlay"
    data-title="Create new project"
    data-placement="left auto">

    As a first step you can create a new project using this link.

    {% include 'overlays/buttons.html'%}
</div>
