# Generated by Django 2.2.13 on 2020-08-24 11:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0020_require_uri_prefix'),
    ]

    operations = [
        migrations.AlterField(
            model_name='condition',
            name='source',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='The attribute of the value for this condition.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='conditions', to='domain.Attribute', verbose_name='Source'),
        ),
        migrations.AlterField(
            model_name='condition',
            name='target_option',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='If using a value pointing to an option, the option this condition is checking against.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='conditions', to='options.Option', verbose_name='Target (Option)'),
        ),
    ]
