{% load i18n %}

    {% if page_obj.has_other_pages %}
    <div class="text-center">
        <ul class="pager">
            {% if page_obj.has_previous %}
            <li class="previous"><a href="?page={{ page_obj.previous_page_number }}">{% trans 'Previous' %}</a></li>
            {% else %}
            <li class="previous disabled"><a href="">{% trans 'Previous' %}</a></li>
            {% endif %}
            <li>
                {% blocktrans trimmed with number=page_obj.number num_pages=page_obj.paginator.num_pages %}
                Page {{ number }} of {{ num_pages }}.
                {% endblocktrans %}
            </li>
            {% if page_obj.has_next %}
            <li class="next"><a href="?page={{ page_obj.next_page_number }}">{% trans 'Next' %}</a></li>
            {% else %}
            <li class="next disabled"><a href="">{% trans 'Next' %}</a></li>
            {% endif %}
        </ul>
    </div>
    {% endif %}
