# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-21 13:14
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0030_data_migration'),
    ]

    operations = [
        migrations.RenameField(
            model_name='question',
            old_name='attribute_entity',
            new_name='attribute',
        ),
        migrations.RenameField(
            model_name='questionset',
            old_name='attribute_entity',
            new_name='attribute',
        ),
    ]
