{% extends 'core/export.html' %}
{% load i18n %}

{% block body %}

    <h1>{% trans 'Domain' %}</h1>

    <ul>

    {% for attribute in attributes %}

    <li>
        <p>
            <strong>{% trans 'URI' %}:</strong> {{ attribute.uri }}
        </p>
    </li>

    {% endfor %}

    </ul>

{% endblock %}
