# Generated by Django 2.2.18 on 2021-05-27 11:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0062_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='questionset',
            name='questionset',
            field=models.ForeignKey(blank=True, default=None, help_text='The question set this question set belongs to.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='questionsets', to='questions.QuestionSet', verbose_name='Question set'),
        ),
    ]
