# Generated by Django 2.2.13 on 2020-09-24 13:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0038_integration_integrationoption'),
    ]

    operations = [
        migrations.AddField(
            model_name='integrationoption',
            name='secret',
            field=models.BooleanField(default=False, help_text='Designates whether this integration option is hidden from regular users.', verbose_name='Secret'),
        ),
    ]
