<div class="overlay" id="projects-table-overlay"
    data-title="Meine Projekte"
    data-placement="bottom">

    Hier finden Sie alle Ihre selbst angelegten Projekte oder Projekte denen Sie hinzugefügt worden sind.
    Zu Beginn wird diese Übersicht leer sein. Die angegebene Rolle (Besitzer, Manager, Autor, Gast) definiert
    Ihre Zugriffsbeschränkung auf das Projekt. Sie können mit Hilfe der Symbole rechts in der jeweiligen Zeile
    die Projekte bearbeiten oder löschen.

    {% include 'overlays/buttons.html'%}
</div>
