# Generated by Django 2.2.18 on 2021-03-22 15:47

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='Overlay',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url_name', models.SlugField(help_text='The url_name for this overlay.', max_length=128, verbose_name='Url name')),
                ('current', models.SlugField(blank=True, help_text='The current state for this overlay.', max_length=128, verbose_name='Current')),
                ('site', models.ForeignKey(help_text='The site for this overlay.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='sites.Site', verbose_name='Site')),
                ('user', models.ForeignKey(help_text='The user for this overlay.', on_delete=django.db.models.deletion.CASCADE, related_name='overlays', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Overlay',
                'verbose_name_plural': 'Overlays',
                'ordering': ('user', 'url_name'),
            },
        ),
    ]
