# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-01 14:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0009_meta'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='questionentity',
            name='label_de',
        ),
        migrations.RemoveField(
            model_name='questionentity',
            name='label_en',
        ),
        migrations.RemoveField(
            model_name='section',
            name='label_de',
        ),
        migrations.RemoveField(
            model_name='section',
            name='label_en',
        ),
        migrations.RemoveField(
            model_name='subsection',
            name='label_de',
        ),
        migrations.RemoveField(
            model_name='subsection',
            name='label_en',
        ),
        migrations.AddField(
            model_name='questionentity',
            name='label',
            field=models.CharField(blank=True, help_text='The label to be displayed this question/questionset (auto-generated).', max_length=512, null=True, verbose_name='Label'),
        ),
        migrations.AddField(
            model_name='section',
            name='label',
            field=models.CharField(blank=True, help_text='The label to be displayed this section (auto-generated).', max_length=512, null=True, verbose_name='Label'),
        ),
        migrations.AddField(
            model_name='subsection',
            name='label',
            field=models.CharField(blank=True, help_text='The label to be displayed this subsection (auto-generated).', max_length=512, null=True, verbose_name='Label'),
        ),
    ]
