# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-08-03 14:31
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0015_label'),
    ]

    operations = []
