<div class="overlay" id="import-project-overlay"
    data-title="Importazione di un progetto esistente"
    data-placement="left auto">

    Se hai già creato ed esportato un progetto in
    RDMO e vuoi aggiungerlo alla tua lista di progetti
    puoi importare un progetto esistente qui.

    {% include 'overlays/buttons.html'%}
</div>
