<div class="overlay" id="project-snapshots-overlay"
    data-title="Snapshots"
    data-placement="top auto">

    Mit Snapshots können Sie alle Antworten zu einem bestimmten Zeitpunkt speichern und eine bestimmte Phase des Projekts einfrieren. Später kann der Snapshot zum Erstellen von Ansichten verwendet werden, und das Projekt kann bei Bedarf auch auf einen früheren Snapshot zurückgesetzt werden.

    {% include 'overlays/buttons.html'%}
</div>
