{% extends 'core/base.html' %}
{% load i18n compress static core_tags %}

{% block head %}
{% compress css %}
<link rel="stylesheet" type="text/x-scss" href="{% static 'core/css/header.scss' %}" />
{% endcompress %}
{% compress js %}
<script type="text/javascript" src="{% static 'core/js/header.js' %}" ></script>
{% endcompress %}
{% endblock %}

{% block content %}

<header>
    <div class="hidden-xs">
        <div class="header-image header-image-0 visible">
            <img src="{% static 'core/img/header/library.jpg' %}"></img>
            <p class="attribution">
                <a href="https://www.flickr.com/photos/spam/5086168739">Stockholm Public Library (Samantha Marx)</a> / <a href="https://creativecommons.org/licenses/by/2.0/">CC BY 2.0</a>
            </p>
        </div>
        <div class="header-image header-image-1">
            <img src="{% static 'core/img/header/supercomputer.jpg' %}"></img>
            <p class="attribution">
                <a href="https://www.flickr.com/photos/nasa_goddard/6559334541">Discover Supercomputer 3 (NASA Goddard Space Flight Center)</a> / <a href="https://creativecommons.org/licenses/by/2.0/">CC BY 2.0</a>
            </p>
        </div>
        <div class="header-image header-image-2">
            <img src="{% static 'core/img/header/collection.jpg' %}"></img>
            <p class="attribution">
                <a href="https://www.flickr.com/photos/bulle_de/9221247815">Nasssammlung (Christopher Bulle)</a> / <a href="https://creativecommons.org/licenses/by/2.0/">CC BY 2.0</a>
            </p>
        </div>
    </div>
    <div class="container header-text">

        <h1>RDMO</h1>

        <div class="row">
            <div class="col-md-9">
                <p>{% trans "A tool to support the planning, implementation, and organisation of research data management." %}</p>
            </div>
        </div>
    </div>
</header>

<div class="container page">
    <div class="row">
        <div class="col-md-9">
            {% render_lang_template "core/home_text" %}
        </div>

        <div class="col-md-3">
            <h3>{% trans 'Login' %}</h3>

            {% include 'account/login_form.html' %}
        </div>
    </div>
</div>

{% endblock %}
