# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-25 11:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0004_conditions'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='optionset',
            options={'ordering': ('key',), 'verbose_name': 'OptionSet', 'verbose_name_plural': 'OptionSets'},
        ),
        migrations.RenameField(
            model_name='option',
            old_name='title',
            new_name='key',
        ),
        migrations.RenameField(
            model_name='optionset',
            old_name='title',
            new_name='key',
        ),
    ]
