# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-04 13:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0028_path'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attributeentity',
            name='path',
            field=models.CharField(db_index=True, help_text='The path part of the URI of this attribute/entity (auto-generated).', max_length=512, verbose_name='Path'),
        ),
    ]
