# Generated by Django 2.2 on 2019-04-20 08:16

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0021_data_migrations'),
    ]

    operations = [
        migrations.AlterField(
            model_name='option',
            name='optionset',
            field=models.ForeignKey(help_text='The option set this option belongs to.', on_delete=django.db.models.deletion.CASCADE, related_name='options', to='options.OptionSet', verbose_name='Option set'),
        ),
    ]
