# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-08-03 12:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0003_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='condition',
            name='title',
            field=models.CharField(default='', max_length=256),
            preserve_default=False,
        ),
    ]
