# Generated by Django 2.2.7 on 2019-11-05 11:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('views', '0021_view_catalogs'),
        ('projects', '0029_remove_manager'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='views',
            field=models.ManyToManyField(blank=True, help_text='The views that will be used for this project.', to='views.View', verbose_name='Views'),
        ),
    ]
