# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-10-24 14:53
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='option',
            name='optionset',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='options', to='options.OptionSet'),
        ),
        migrations.AlterField(
            model_name='option',
            name='order',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='optionset',
            name='order',
            field=models.IntegerField(default=0),
        ),
    ]
