{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans 'Bad request' %}</h1>

    <p>{% trans 'Sorry, but there is something wrong with your HTTP request.' %}</p>

{% endblock %}
