<div class="row">
    <div class="footer-col col-md-4">
        <h4>Über RDMO</h4>
        <p>
            Der Research Data Management Organiser unterstützt die systematische Planung, Organisation und Durchführung des Datenmanagements im Verlauf eines Forschungsprojekts.
        </p>
        <p>
            RDMO ist eine Open-Source-Software und unter <a href="https://github.com/rdmorganiser/rdmo">https://github.com/rdmorganiser/rdmo</a> verfügbar.
        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Kontakt</h4>
        <p>

        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Impressum und Datenschutz</h4>
        <p>

        </p>
    </div>
</div>
