# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-27 12:47
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0007_permissions'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='task',
            name='attribute',
        ),
        migrations.RemoveField(
            model_name='task',
            name='time_period',
        ),
    ]
