# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-05 14:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0012_meta'),
        ('questions', '0016_data_migration'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='optionsets',
            field=models.ManyToManyField(blank=True, help_text='Option sets for this question.', to='options.OptionSet', verbose_name='Option sets'),
        ),
    ]
