{% load static %}
{% load core_tags %}
{% load i18n %}

<div class="text-center">
    <img class="rdmo-logo" src="{% static 'core/img/rdmo-logo.svg' %}" alt="{% trans 'RDMO Logo' %}" />

    <h1>Research data management organiser</h1>

    <h4>Version {% version %}</h4>
</div>

<div class="text-justify">
    <p>
        Mit dem Research Data Management Organiser (RDMO) können Institutionen und Forschende das Forschungsdatenmanagement ihre Projekte strukturiert planen und durchführen. Es erlaubt das Erfassen aller relevanten Planungsinformationen in Datenmanagementplänen und die Verwaltung aller Datenmanagementaufgaben über den gesamten Datenlebenszyklus.
    </p>

    <p>
        RDMO ist bereit für die Anwendung in kleineren und größeren Projekten. In der zweiten Phase des RDMO-Projekts seit November 2017 erweitern die Projektpartner AIP, FHP und KIT-Bibliothek die bereits veröffentlichte Version des RDMO und arbeiten vertieft mit Anwendern zusammen. Im Fokus der Erweiterung von RDMO stehen u.a. Rollenkonzepte und Anbindungen an die institutionelle Infrastruktur wie Repositorien, Ticket-Systeme und Infrastruktur für Authentifizierung und Autorisierung. Es werden Workshops zur Diskussion der Funktionalitäten durchgeführt, Einführungsmaterialien erstellt und eine Verbreiterung der Entwickler-Community angestrebt.
    </p>

    <p>
        Mehr Informationen über RDMO finden sie auf <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
    </p>
</div>
