# Generated by Django 2.2rc1 on 2019-03-26 13:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0025_remove_null_true'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='membership',
            options={'ordering': ('project__title',), 'verbose_name': 'Membership', 'verbose_name_plural': 'Memberships'},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'ordering': ('title',), 'verbose_name': 'Project', 'verbose_name_plural': 'Projects'},
        ),
        migrations.AlterModelOptions(
            name='snapshot',
            options={'ordering': ('project', '-created'), 'verbose_name': 'Snapshot', 'verbose_name_plural': 'Snapshots'},
        ),
        migrations.AlterModelOptions(
            name='value',
            options={'ordering': ('attribute', 'set_index', 'collection_index'), 'verbose_name': 'Value', 'verbose_name_plural': 'Values'},
        ),
        migrations.AlterField(
            model_name='snapshot',
            name='project',
            field=models.ForeignKey(help_text='The project this snapshot belongs to.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='snapshots', to='projects.Project', verbose_name='Project'),
        ),
    ]
