<div class="overlay" id="project-memberships-overlay"
    data-title="Membres"
    data-placement="top auto">

    Ici, vous pouvez voir qui peut accéder au projet et inviter des membres supplémentaires.  Les droits d'utilisation peuvent être gérés par les rôles. Les membres peuvent être supprimés à l'aide du symbole de la croix.

    {% include 'overlays/buttons.html'%}
</div>
