# Generated by Django 2.2.13 on 2020-08-31 16:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0035_data_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='project',
            name='tasks',
        ),
    ]
