{% extends 'core/page.html' %}
{% load i18n %}
{% load core_tags %}

{% block page %}

    <h1>{% trans "Delete project" %}</h1>

    <p>
        {% blocktrans trimmed %}
        You are about to permanently delete the project <strong>{{ object }}</strong>.
        {% endblocktrans %}

        {% if object.get_children %}
        {% if object.parent %}

        {% blocktrans with parent=object.parent trimmed %}
        Descendant projects will be moved to the project <strong>{{ parent }}</strong>.
        {% endblocktrans %}

        {% else %}

        {% trans 'Descendant projects will be preserved.' %}

        {% endif %}
        {% endif %}
    </p>

    <p class="text-danger">
        {% trans 'This action cannot be undone!' %}
    </p>

    {% bootstrap_delete_form submit=_('Delete project') %}

{% endblock %}
