# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-08-09 12:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0002_meta'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='description',
            field=models.TextField(blank=True, help_text='Optional', verbose_name='description'),
        ),
    ]
