{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

<h1>{% trans "E-mail Addresses" %}</h1>

{% if user.emailaddress_set.all %}

<p>{% trans 'The following e-mail addresses are associated with your account:' %}</p>

<form class="email-form" action="{% url 'account_email' %}" class="email_list" method="post">
    {% csrf_token %}

    <fieldset>

        {% for emailaddress in user.emailaddress_set.all %}

        <label for="email_radio_{{forloop.counter}}" class="{% if emailaddress.primary %}primary_email{%endif%}">
            <input id="email_radio_{{forloop.counter}}" type="radio" name="email" {% if emailaddress.primary or user.emailaddress_set.count == 1 %}checked="checked"{%endif %} value="{{emailaddress.email}}"/>

            {{ emailaddress.email }}

            <div class="pull-right">
                {% if emailaddress.primary %}
                <span class="label label-primary">{% trans "Primary" %}</span>
                {% endif %}

                {% if emailaddress.verified %}
                <span class="label label-success">{% trans "Verified" %}</span>
                {% else %}
                <span class="label label-warning">{% trans "Unverified" %}</span>
                {% endif %}
            </div>
        </label>

        {% endfor %}

        <div class="email-form-buttons">
            <button class="btn btn-default" type="submit" name="action_primary" >{% trans 'Make Primary' %}</button>
            <button class="btn btn-default" type="submit" name="action_send" >{% trans 'Re-send Verification' %}</button>
            <button class="btn btn-primary" type="submit" name="action_remove" >{% trans 'Remove' %}</button>
        </div>

    </fieldset>
</form>

{% else %}

<p>
    <strong>{% trans 'Warning:'%}</strong> {% trans "You currently do not have any e-mail address set up. You should really add an e-mail address so you can receive notifications, reset your password, etc." %}
</p>

{% endif %}

<h2>{% trans "Add E-mail Address" %}</h2>

<form method="post" action="{% url 'account_email' %}" class="add_email">
    {% csrf_token %}

    {% include 'core/bootstrap_form_fields.html' %}

    <button class="btn btn-default" name="action_add" type="submit">{% trans "Add E-mail" %}</button>
</form>

{% endblock %}

{% block extra_body %}
<script type="text/javascript">
    (function() {
        var message = "{% trans 'Do you really want to remove the selected e-mail address?' %}";
        var actions = document.getElementsByName('action_remove');
        if (actions.length) {
            actions[0].addEventListener("click", function(e) {
                if (! confirm(message)) {
                    e.preventDefault();
                }
            });
        }
    })();
</script>
{% endblock %}
