{% load i18n %}

    <p class="text-muted">
        {% blocktrans trimmed %}
        Snapshots allow you to save all responses at a given point in time and preserve a certain stage of the project. Later the snapshot can be used to create views, and the project can also be reset to a previous snapshot if needed.
        {% endblocktrans %}
    </p>
