# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2019-03-05 14:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0039_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='catalog',
            name='title_lang3',
            field=models.CharField(blank=True, help_text='The title for this catalog in the tertiary language.', max_length=256, null=True, verbose_name='Title (tertiary)'),
        ),
        migrations.AddField(
            model_name='catalog',
            name='title_lang4',
            field=models.CharField(blank=True, help_text='The title for this catalog in the quaternary language.', max_length=256, null=True, verbose_name='Title (quaternary)'),
        ),
        migrations.AddField(
            model_name='catalog',
            name='title_lang5',
            field=models.CharField(blank=True, help_text='The title for this catalog in the quinary language.', max_length=256, null=True, verbose_name='Title (quinary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='help_lang3',
            field=models.TextField(blank=True, help_text='The help text for this question in the tertiary language.', null=True, verbose_name='Help (tertiary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='help_lang4',
            field=models.TextField(blank=True, help_text='The help text for this question in the quaternary language.', null=True, verbose_name='Help (quaternary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='help_lang5',
            field=models.TextField(blank=True, help_text='The help text for this question in the quinary language.', null=True, verbose_name='Help (quinary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='text_lang3',
            field=models.TextField(blank=True, help_text='The text for this question in the tertiary language.', null=True, verbose_name='Text (tertiary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='text_lang4',
            field=models.TextField(blank=True, help_text='The text for this question in the quaternary language.', null=True, verbose_name='Text (quaternary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='text_lang5',
            field=models.TextField(blank=True, help_text='The text for this question in the quinary language.', null=True, verbose_name='Text (quinary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_lang3',
            field=models.CharField(blank=True, help_text='The name displayed for this question in the tertiary language.', max_length=256, verbose_name='Name (tertiary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_lang4',
            field=models.CharField(blank=True, help_text='The name displayed for this question in the quaternary language.', max_length=256, verbose_name='Name (quaternary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_lang5',
            field=models.CharField(blank=True, help_text='The name displayed for this question in the quinary language.', max_length=256, verbose_name='Name (quinary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_plural_lang3',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the tertiary language.', max_length=256, verbose_name='Plural name (tertiary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_plural_lang4',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the quaternary language.', max_length=256, verbose_name='Plural name (quaternary)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_plural_lang5',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the quinary language.', max_length=256, verbose_name='Plural name (quinary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='help_lang3',
            field=models.TextField(blank=True, help_text='The help text for this questionset in the tertiary language.', null=True, verbose_name='Help (tertiary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='help_lang4',
            field=models.TextField(blank=True, help_text='The help text for this questionset in the quaternary language.', null=True, verbose_name='Help (quaternary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='help_lang5',
            field=models.TextField(blank=True, help_text='The help text for this questionset in the quinary language.', null=True, verbose_name='Help (quinary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='title_lang3',
            field=models.CharField(blank=True, help_text='The title for this questionset in the tertiary language.', max_length=256, null=True, verbose_name='Title (tertiary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='title_lang4',
            field=models.CharField(blank=True, help_text='The title for this questionset in the quaternary language.', max_length=256, null=True, verbose_name='Title (quaternary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='title_lang5',
            field=models.CharField(blank=True, help_text='The title for this questionset in the quinary language.', max_length=256, null=True, verbose_name='Title (quinary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_lang3',
            field=models.CharField(blank=True, help_text='The  name displayed for this question in the tertiary language.', max_length=256, verbose_name='Name (tertiary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_lang4',
            field=models.CharField(blank=True, help_text='The  name displayed for this question in the quaternary language.', max_length=256, verbose_name='Name (quaternary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_lang5',
            field=models.CharField(blank=True, help_text='The  name displayed for this question in the quinary language.', max_length=256, verbose_name='Name (quinary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_plural_lang3',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the tertiary language.', max_length=256, verbose_name='Plural name (tertiary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_plural_lang4',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the quaternary language.', max_length=256, verbose_name='Plural name (quaternary)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_plural_lang5',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the quinary language.', max_length=256, verbose_name='Plural name (quinary)'),
        ),
        migrations.AddField(
            model_name='section',
            name='title_lang3',
            field=models.CharField(blank=True, help_text='The title for this section in the tertiary language.', max_length=256, null=True, verbose_name='Title (tertiary)'),
        ),
        migrations.AddField(
            model_name='section',
            name='title_lang4',
            field=models.CharField(blank=True, help_text='The title for this section in the quaternary language.', max_length=256, null=True, verbose_name='Title (quaternary)'),
        ),
        migrations.AddField(
            model_name='section',
            name='title_lang5',
            field=models.CharField(blank=True, help_text='The title for this section in the quinary language.', max_length=256, null=True, verbose_name='Title (quinary)'),
        ),
        migrations.AlterField(
            model_name='catalog',
            name='title_lang1',
            field=models.CharField(blank=True, help_text='The title for this catalog in the primary language.', max_length=256, null=True, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='catalog',
            name='title_lang2',
            field=models.CharField(blank=True, help_text='The title for this catalog in the secondary language.', max_length=256, null=True, verbose_name='Title (secondary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='text_lang1',
            field=models.TextField(blank=True, help_text='The text for this question in the primary language.', null=True, verbose_name='Text (primary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='text_lang2',
            field=models.TextField(blank=True, help_text='The text for this question in the secondary language.', null=True, verbose_name='Text (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang1',
            field=models.CharField(blank=True, help_text='The title for this questionset in the primary language.', max_length=256, null=True, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang2',
            field=models.CharField(blank=True, help_text='The title for this questionset in the secondary language.', max_length=256, null=True, verbose_name='Title (secondary)'),
        ),
        migrations.AlterField(
            model_name='section',
            name='title_lang1',
            field=models.CharField(blank=True, help_text='The title for this section in the primary language.', max_length=256, null=True, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='section',
            name='title_lang2',
            field=models.CharField(blank=True, help_text='The title for this section in the secondary language.', max_length=256, null=True, verbose_name='Title (secondary)'),
        ),
    ]
