# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-27 15:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0006_refactoring'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='option',
            options={'ordering': ('uri',), 'verbose_name': 'Option', 'verbose_name_plural': 'Options'},
        ),
        migrations.AlterModelOptions(
            name='optionset',
            options={'ordering': ('uri',), 'verbose_name': 'Option set', 'verbose_name_plural': 'Option sets'},
        ),
    ]
