{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

{% if token_fail %}

    <h1>{% trans "Bad token" %}</h1>

    <p>
        {% url 'account_reset_password' as passwd_reset_url %}
        {% blocktrans trimmed %}The password reset link was invalid, possibly because it has already been used.
        Please request a <a href="{{ passwd_reset_url }}">new password reset</a>.{% endblocktrans %}
    </p>

{% else %}

    <h1>{% trans "Enter new password" %}</h1>

    {% if form %}

    <form method="post" action=".">
        {% csrf_token %}

        {% include 'core/bootstrap_form_fields.html' %}

        <input type="submit" class="btn btn-primary" value="{% trans 'Change my password' %}" />
    </form>

    {% else %}

    <p>
        {% trans 'Your password is now changed.' %}
    </p>

    {% endif %}

{% endif %}

{% endblock %}
