# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-10-21 09:42
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0018_validator'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='attribute',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='attributeentity',
            managers=[
            ],
        ),
    ]
