{% load i18n %}

    <i class="fa fa-lock text-muted" ng-show="section.locked || service.catalog.locked"></i>
    <i class="fa fa-lock text-danger" ng-show="questionset.locked"></i>

    <a href="" class="fa fa-plus"
        title="{% trans 'Add question' %}"
        ng-click="service.openFormModal('questions', questionset, true)">
    </a>

    <a href="" class="fa fa-plus-square"
        title="{% trans 'Add question set' %}"
        ng-click="service.openFormModal('questionsets', questionset, true)">
    </a>

    <a href="" class="fa fa-pencil"
        title="{% trans 'Update question set' %}"
        ng-click="service.openFormModal('questionsets', questionset)">
    </a>

    <a href="" class="fa fa-copy"
        title="{% trans 'Copy question set' %}"
        ng-click="service.openFormModal('questionsets', questionset, false, true)">
    </a>

    <a href="{$ questionset.xml_url $}" class="fa fa-download"
        title="{% trans 'Export question set as XML' %}"
        target="blank">
    </a>

    <a href="" class="fa fa-trash"
        title="{% trans 'Delete question set' %}"
        ng-click="service.openDeleteModal('questionsets', questionset)">
    </a>
