# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-01-30 14:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0015_rename_de_to_lang2'),
    ]

    operations = [
        migrations.AlterField(
            model_name='option',
            name='text_lang1',
            field=models.CharField(help_text='The text for this option in the primary language.', max_length=256, verbose_name='Text (primary)'),
        ),
        migrations.AlterField(
            model_name='option',
            name='text_lang2',
            field=models.CharField(help_text='The text for this option in the secondary language.', max_length=256, verbose_name='Text (secondary)'),
        ),
    ]
