{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Password reset sent" %}</h1>

    {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
    {% endif %}

    <p>
        {% blocktrans trimmed %}
        We have sent you an e-mail. Please contact us if you do not receive it within a few minutes.
        {% endblocktrans %}
    </p>

    <p>
        {% blocktrans trimmed %}
        If you don't receive an e-mail, please make sure you've entered the address you registered with, and check your spam folder.
        {% endblocktrans %}
    </p>

{% endblock %}
