<div class="overlay" id="issue-message-overlay"
    data-title="Messaggio"
    data-placement="bottom">

    I compiti spesso ti chiedono di contattare un altro dipartimento. Qui troverai un messaggio pronto con le persone di contatto interessate come destinatari, che puoi inviare qui come e-mail.

    {% include 'overlays/buttons.html'%}
</div>
