# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-28 12:34
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0006_meta'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='task',
            options={'ordering': ('uri',), 'permissions': (('view_task', 'Can view Task'),), 'verbose_name': 'Task', 'verbose_name_plural': 'Tasks'},
        ),
    ]
