<div class="overlay" id="create-project-overlay"
    data-title="Neues Projekt anlegen"
    data-placement="left auto">

    Als ersten Schritt können Sie mit diesem Link ein neues Projekt anlegen.

    {% include 'overlays/buttons.html'%}
</div>
