# Generated by Django 2.2.13 on 2020-08-31 15:07

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0031_related_name'),
        ('projects', '0033_default_value_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='Issue',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('open', 'open'), ('in_progress', 'in progress'), ('closed', 'closed')], default='open', help_text='The status for this issue.', max_length=12, verbose_name='Status')),
                ('project', models.ForeignKey(help_text='The project for this issue.', on_delete=django.db.models.deletion.CASCADE, related_name='issues', to='projects.Project', verbose_name='Project')),
                ('task', models.ForeignKey(help_text='The task for this issue.', on_delete=django.db.models.deletion.CASCADE, related_name='issues', to='tasks.Task', verbose_name='Task')),
            ],
            options={
                'verbose_name': 'Issue',
                'verbose_name_plural': 'Issues',
                'ordering': ('project__title',),
            },
        ),
    ]
