<div class="overlay" id="projects-table-overlay"
    data-title="Mes projets"
    data-placement="bottom">

    Vous trouverez ici tous les projets que vous avez créés vous-même, ainsi que les projets auxquels vous avez été ajouté.
    Au début, cet aperçu sera vide. Le rôle spécifié (propriétaire, gestionnaire, auteur, invité) définit
    votre restriction d'accès au projet. Vous pouvez éditer ou supprimer les projets à l'aide de
    des symboles situés à droite dans la ligne correspondante.

    {% include 'overlays/buttons.html'%}
</div>
