{% load i18n %}

    <div class="modal" id="tasks-delete-modal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h2 class="modal-title" id="add-modal">
                        {% trans 'Delete task' %}
                    </h2>
                </div>

                <div class="modal-body">
                    <p>
                        {% blocktrans trimmed with object='{$ service.values.uri $}' %}
                        You are about to permanently delete the task <code>{{ object }}</code>.
                        {% endblocktrans %}
                    </p>

                    <p class="text-danger">
                        {% trans 'This action cannot be undone!' %}
                    </p>
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">
                        {% trans 'Close' %}
                    </button>
                    <button type="button" class="btn btn-danger"
                            ng-click="service.submitDeleteModal('tasks')">
                        {% trans 'Delete' %}
                    </button>
                </div>
            </div>
        </div>
    </div>
