<h2>Bienvenue sur RDMO</h2>

<p>
    L'objectif du projet RDMO est de fournir une application web pour aider à la planification structurée, à la mise en œuvre et à l'administration des données d'un projet scientifique. En outre, les informations recueillies peuvent être transposées sous forme textuelle pour répondre aux exigences des organismes de financement ou pour les rapports.
</p>

<p>
    Il s'agit d'un prototype du logiciel, à des fins de démonstration.
</p>

<p>
    Pour plus d'informations sur le projet, visitez <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
</p>
