<div class="overlay" id="projects-table-overlay"
    data-title="I miei progetti"
    data-placement="bottom">

    Qui troverai tutti i tuoi progetti creati da te, così come i progetti a cui sei stato aggiunto.
    All'inizio questa panoramica sarà vuota. Il ruolo specificato (proprietario, manager, autore, ospite) definisce
    le tue restrizioni di accesso al progetto. Puoi modificare o cancellare i progetti con l'aiuto
    dei simboli a destra nella rispettiva riga.

    {% include 'overlays/buttons.html'%}
</div>
