{% load i18n %}
{% load socialaccount %}

{% get_providers as socialaccount_providers %}

{% if socialaccount_providers %}

<p>
    {% blocktrans with site.name as site_name %}Alternatively, you can login using one of the following third party accounts:{% endblocktrans %}
</p>

<div class="socialaccount_ballot">
    <ul class="socialaccount_providers">
    {% include "socialaccount/snippets/provider_list.html" with process="login" %}
    </ul>
</div>

{% include "socialaccount/snippets/login_extra.html" %}

{% endif %}
