# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-07-26 14:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0008_meta'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='condition',
            name='attribute_entity',
        ),
        migrations.RemoveField(
            model_name='condition',
            name='source_attribute',
        ),
        migrations.RemoveField(
            model_name='condition',
            name='target_option',
        ),
        migrations.DeleteModel(
            name='Condition',
        ),
    ]
