<div class="overlay" id="project-issues-overlay"
    data-title="Aufgaben"
    data-placement="bottom auto">

    Aufgaben werden automatisch aus den in den Fragenkatalogen von Ihnen gegebenen Antworten generiert. Auf der Seite jeder Aufgabe können Sie sehen, welche Ihrer Antworten zur Aktivierung der Aufgabe führen. Außerdem können Sie den Status Ihrer zu erledigenden Aufgaben mit dem Stiftsymbol ändern, wenn Sie eine Aufgabe begonnen oder beendet haben. Mit dem Papierflieger-Symbol können Sie eine E-Mail schicken und ggf. eine Ansicht im gewünschten Format als Anhang anfügen. Zu Beginn ist die Übersicht der Aufgaben leer.

    {% include 'overlays/buttons.html'%}
</div>
