<div class="overlay" id="project-questions-overlay"
    data-title="Rispondi alle domande"
    data-placement="left auto">

    Clicca a questo punto su "Rispondi alle domande" per andare all'intervista del questionario selezionato.
    Le tue risposte saranno utilizzate per creare compiti individuali per te, che troverai nella
    nella panoramica dei compiti, così come per compilare modelli già pronti che puoi esportare per un ulteriore utilizzo.

    {% include 'overlays/buttons.html'%}
</div>
