<div class="overlay" id="issue-message-overlay"
    data-title="Message"
    data-placement="bottom">

    The tasks often ask you to contact another department. Here you will find a ready-made message with the relevant contact persons as recipients, which you can send here as an e-mail.

    {% include 'overlays/buttons.html'%}
</div>
