# Generated by Django 2.2.16 on 2021-01-22 19:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0021_related_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='condition',
            name='locked',
            field=models.BooleanField(default=False, help_text='Designates whether this condition can be changed.', verbose_name='Locked'),
        ),
    ]
