# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-30 12:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0005_data_migration'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='task',
            options={'ordering': ('uri',), 'verbose_name': 'Task', 'verbose_name_plural': 'Tasks'},
        ),
    ]
