{% load i18n %}

    <p class="text-muted">
        {% blocktrans trimmed %}
        Integrations can be used to send tasks to various external tools. Please follow the descriptions of the integrations to use them.
        {% endblocktrans %}
    </p>
