{% load static %}
{% load core_tags %}
{% load i18n %}

<div class="text-center">
    <img class="rdmo-logo" src="{% static 'core/img/rdmo-logo.svg' %}" alt="{% trans 'RDMO Logo' %}" />

    <h1>Research data management organiser</h1>

    <h4>Version {% version %}</h4>
</div>

<div class="text-justify">
    <p>
        RDMO permet aux institutions ainsi qu'aux chercheurs de planifier et de réaliser leur gestion des données de recherche. RDMO peut rassembler toutes les informations de planification pertinentes et les tâches de gestion des données tout au long du cycle de vie des données de recherche.
    </p>

    <p>
        RDMO est prêt à être appliqué dans des projets plus ou moins importants. Dans la prochaine phase du projet, qui a débuté en novembre 2017, l'outil RDMO sera étendu et les partenaires du projet, l'AIP, la FHP et la bibliothèque du KIT, collaboreront avec les utilisateurs de RDMO pour améliorer son utilisation. L'outil sera étendu en améliorant sa mise en œuvre des rôles et des interfaces avec l'infrastructure institutionnelle, par exemple les dépôts, les systèmes de billetterie, et l'infrastructure d'authentification et d'autorisation. Des tutoriels, de la documentation et d'autres matériels sont prévus pour la diffusion, ainsi que des ateliers pour les utilisateurs et les développeurs.
    </p>

    <p>
        De plus amples informations sur RDMO sont disponibles sur <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
    </p>
</div>
