{% load i18n %}

    <div class="modal" id="valuesets-form-modal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h2 class="modal-title">
                        {$ service.questionset.verbose_name | capitalize $}
                    </h2>
                </div>

                <div class="modal-body">
                    <formgroup
                        data-id="modal-title-input"
                        data-type="text"
                        data-label="{% trans 'Title' %}"
                        data-help="{% blocktrans with name='{$ service.questionset.verbose_name $}' %}Please give the {{ name }} a meaningful name.{% endblocktrans %}"
                        data-model="service.modal_values.text"
                        data-errors="service.modal_errors.text">
                    </formgroup>
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">
                        {% trans 'Close' %}
                    </button>
                    <button type="button" class="btn btn-success"
                            ng-click="service.submitValueSetFormModal()">
                        {% trans 'Save' %}
                    </button>
                </div>
            </div>
        </div>
    </div>
