{% extends 'core/page.html' %}
{% load i18n %}
{% load core_tags %}

{% block page %}

    <h1>{% trans "Password reset complete" %}</h1>

    <p>
        {% trans "Your password has been set. You may go ahead and log in now." %}
    </p>

    <p>
        <a href="{% url 'account_login' %}">{% trans 'Login' %}</a>
    </p>

{% endblock %}
