{% load i18n %}

    <div class="form-group" ng-if="question.widget_type === 'yesno'">
        {% include 'projects/project_questions_question_label.html' %}
        {% include 'projects/project_questions_question_help.html' %}
        {% include 'projects/project_questions_question_warning.html' %}

        <div ng-if="question.is_collection">
            {% include 'projects/project_questions_add_field_help.html' %}
        </div>

        <div ng-repeat="value in service.values[question.attribute][valueset.set_prefix][valueset.set_index] track by $index">
            <div class="collection" ng-hide="value.removed">
                <div class="radio-control">

                    <div class="options">
                        {% include 'projects/project_questions_default.html' %}
                        {% include 'projects/project_questions_erase_field.html' %}
                        {% include 'projects/project_questions_remove_field.html' %}
                    </div>

                    <div class="radio yesno">
                        <label>
                            <input type="radio" value="1"
                                ng-model="value.text"
                                ng-disabled="service.project.read_only"
                                ng-change="service.changed(value, true)"
                                ng-class="{'default-value': service.isDefaultValue(question, value) &&
                                                            value.text == '1'}" />
                            <span>{% trans 'Yes' %}</span>
                        </label>
                        <label class=>
                            <input type="radio" value="0"
                                ng-model="value.text"
                                ng-disabled="service.project.read_only"
                                ng-change="service.changed(value, true)"
                                ng-class="{'default-value': service.isDefaultValue(question, value) &&
                                                            value.text == '0'}" />
                            <span>{% trans 'No' %}</span>
                        </label>
                    </div>
                </div>
            </div>
        </div>

        <div ng-if="question.is_collection">
            {% include 'projects/project_questions_add_field_button.html' %}
        </div>
    </div>
