{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Password reset" %}</h1>

    {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
    {% endif %}

    <p>
        {% trans "Forgotten your password? Enter your e-mail address below, and we'll send you an e-mail allowing you to reset it." %}
    </p>

    <form method="post" action="{% url 'account_reset_password' %}">
        {% csrf_token %}

        {% include 'core/bootstrap_form_fields.html' %}

        <input type="submit" class="btn btn-primary" value="{% trans 'Reset my password' %}" />
    </form>

{% endblock %}
