# Generated by Django 2.2.18 on 2021-03-29 10:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0055_catalog_locked'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='is_optional',
            field=models.BooleanField(default=False, help_text='Designates whether this question is optional.', verbose_name='is optional'),
        ),
    ]
