# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-21 13:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0015_move_attribute_to_attributeentity'),
        ('projects', '0022_move_attribute_to_attributeentity'),
        ('tasks', '0012_move_attribute_to_attributeentity'),
        ('domain', '0036_remove_range_and_verbosename')
    ]

    operations = [
        # add a dummy field so that the table does not become empty after the next step
        # otherwise MySQL and SQLite will complain
        # https://code.djangoproject.com/ticket/24424
        migrations.AddField(
            model_name='attribute',
            name='_',
            field=models.BooleanField(default=False),
        ),
        migrations.RemoveField(
            model_name='attribute',
            name='attributeentity_ptr',
        ),
        migrations.DeleteModel(
            name='Attribute',
        ),
    ]
