# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-06 15:02
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0033_remove_attribute_optionsets'),
        ('questions', '0020_data_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='attributeentity',
            name='conditions',
        ),
    ]
