# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-22 10:04
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('accounts', '0009_proxyuser'),
    ]

    operations = [
        migrations.CreateModel(
            name='ConsentFieldValue',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('consent', models.BooleanField(default=False, help_text='Designates whether the user has agreed to the terms of use.', verbose_name='Consent')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('user',),
                'verbose_name': 'Consent field value',
                'verbose_name_plural': 'Consent field values',
            },
        ),
    ]
