<div class="overlay" id="project-views-overlay"
    data-title="Views"
    data-placement="bottom auto">

    The views are templates for forms/documents. The views are automatically filled in based on the answers given in the questionnaire and can then be exported and sent in different formats. At the beginning, all views are empty. In order for the templates to be filled in completely, all relevant questions must be answered. Answers that are used in several templates are automatically transferred to all question catalogues and views.

    {% include 'overlays/buttons.html'%}
</div>
