# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-01-30 14:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0038_rename_de_to_lang2'),
    ]

    operations = [
        migrations.AlterField(
            model_name='catalog',
            name='title_lang1',
            field=models.CharField(help_text='The title for this catalog in the primary language.', max_length=256, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='catalog',
            name='title_lang2',
            field=models.CharField(help_text='The title for this catalog in the secondary language.', max_length=256, verbose_name='Title (secondary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='help_lang1',
            field=models.TextField(blank=True, help_text='The help text for this question in the primary language.', null=True, verbose_name='Help (primary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='help_lang2',
            field=models.TextField(blank=True, help_text='The help text for this question in the secondary language.', null=True, verbose_name='Help (secondary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='text_lang1',
            field=models.TextField(help_text='The text for this question in the primary language.', verbose_name='Text (primary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='text_lang2',
            field=models.TextField(help_text='The text for this question in the secondary language.', verbose_name='Text (secondary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='verbose_name_lang1',
            field=models.CharField(blank=True, help_text='The name displayed for this question in the primary language.', max_length=256, verbose_name='Name (primary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='verbose_name_lang2',
            field=models.CharField(blank=True, help_text='The name displayed for this question in the secondary language.', max_length=256, verbose_name='Name (secondary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='verbose_name_plural_lang1',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the primary language.', max_length=256, verbose_name='Plural name (primary)'),
        ),
        migrations.AlterField(
            model_name='question',
            name='verbose_name_plural_lang2',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the secondary language.', max_length=256, verbose_name='Plural name (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang1',
            field=models.TextField(blank=True, help_text='The help text for this questionset in the primary language.', null=True, verbose_name='Help (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang2',
            field=models.TextField(blank=True, help_text='The help text for this questionset in the secondary language.', null=True, verbose_name='Help (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang1',
            field=models.CharField(help_text='The title for this questionset in the primary language.', max_length=256, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang2',
            field=models.CharField(help_text='The title for this questionset in the secondary language.', max_length=256, verbose_name='Title (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang1',
            field=models.CharField(blank=True, help_text='The name displayed for this question in the primary language.', max_length=256, verbose_name='Name (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang2',
            field=models.CharField(blank=True, help_text='The  name displayed for this question in the secondary language.', max_length=256, verbose_name='Name (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang1',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the primary language.', max_length=256, verbose_name='Plural name (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang2',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question in the secondary language.', max_length=256, verbose_name='Plural name (secondary)'),
        ),
        migrations.AlterField(
            model_name='section',
            name='title_lang1',
            field=models.CharField(help_text='The title for this section in the primary language.', max_length=256, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='section',
            name='title_lang2',
            field=models.CharField(help_text='The title for this section in the secondary language.', max_length=256, verbose_name='Title (secondary)'),
        ),
    ]
