# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-03 13:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0010_label'),
    ]

    operations = [
        migrations.RenameField(
            model_name='questionentity',
            old_name='label',
            new_name='path',
        ),
        migrations.RenameField(
            model_name='section',
            old_name='label',
            new_name='path',
        ),
        migrations.RenameField(
            model_name='subsection',
            old_name='label',
            new_name='path',
        ),
    ]
