# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-08-11 13:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0006_db_constraint_false'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='condition',
            options={'ordering': ('title',), 'verbose_name': 'Condition', 'verbose_name_plural': 'Conditions'},
        ),
    ]
