<div class="overlay" id="import-project-overlay"
    data-title="Importer un projet existant"
    data-placement="left auto">

    Si vous avez déjà créé et exporté un projet dans
    RDMO et que vous souhaitez l'ajouter à votre liste de projets,
    vous pouvez importer un projet existant ici.

    {% include 'overlays/buttons.html'%}
</div>
