# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-04 14:10
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0009_timeframe'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='comment',
            field=models.TextField(blank=True, help_text='Additional internal information about this task.', null=True, verbose_name='Comment'),
        ),
        migrations.AlterField(
            model_name='task',
            name='key',
            field=models.SlugField(blank=True, help_text='The internal identifier of this task.', max_length=128, null=True, verbose_name='Key'),
        ),
        migrations.AlterField(
            model_name='timeframe',
            name='days_after',
            field=models.IntegerField(blank=True, help_text='Additional days after the end date.', null=True, verbose_name='Days after'),
        ),
        migrations.AlterField(
            model_name='timeframe',
            name='days_before',
            field=models.IntegerField(blank=True, help_text='Additional days before the start date.', null=True, verbose_name='Days before'),
        ),
        migrations.AlterField(
            model_name='timeframe',
            name='end_attribute',
            field=models.ForeignKey(blank=True, help_text='The Attribute that is setting the end date for this task (optional, if no end date attribute is given, the start date attribute sets also the end date).', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='domain.Attribute', verbose_name='End date attribute'),
        ),
    ]
