# Generated by Django 2.2.2 on 2019-06-25 13:36

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('accounts', '0016_remove_null_true'),
    ]

    operations = [
        migrations.CreateModel(
            name='Role',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('manager', models.ManyToManyField(help_text='The sites for which this user is manager.', related_name='managers', to='sites.Site', verbose_name='Manager')),
                ('member', models.ManyToManyField(help_text='The sites for which this user is a member.', related_name='members', to='sites.Site', verbose_name='Member')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Roles',
                'verbose_name': 'Role',
                'ordering': ('user',),
            },
        ),
    ]
