# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-10-27 10:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('conditions', '0009_options'),
        ('options', '0003_data_migration'),
    ]

    operations = [
        migrations.AddField(
            model_name='optionset',
            name='conditions',
            field=models.ManyToManyField(blank=True, to='conditions.Condition'),
        ),
    ]
