# Generated by Django 2.2rc1 on 2019-03-26 13:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0042_remove_null_true'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='catalog',
            options={'ordering': ('order',), 'verbose_name': 'Catalog', 'verbose_name_plural': 'Catalogs'},
        ),
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ('questionset', 'order'), 'verbose_name': 'Question', 'verbose_name_plural': 'Questions'},
        ),
        migrations.AlterModelOptions(
            name='questionset',
            options={'ordering': ('section', 'order'), 'verbose_name': 'Question set', 'verbose_name_plural': 'Question set'},
        ),
        migrations.AlterModelOptions(
            name='section',
            options={'ordering': ('catalog__order', 'order'), 'verbose_name': 'Section', 'verbose_name_plural': 'Sections'},
        ),
    ]
