{% extends 'core/export.html' %}
{% load i18n %}

{% block body %}

    <h1>{% blocktrans with title=project.title %}Answers for <em>{{ title }}</em>{% endblocktrans%}</h1>

    {% include 'projects/project_answers_tree.html' %}

{% endblock %}
