# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-08-03 14:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0004_full_title'),
    ]

    operations = [
        migrations.RenameField(
            model_name='section',
            old_name='full_title_de',
            new_name='label_de',
        ),
        migrations.RenameField(
            model_name='section',
            old_name='full_title_en',
            new_name='label_en',
        ),
        migrations.RenameField(
            model_name='subsection',
            old_name='full_title_de',
            new_name='label_de',
        ),
        migrations.RenameField(
            model_name='subsection',
            old_name='full_title_en',
            new_name='label_en',
        ),
        migrations.AddField(
            model_name='questionentity',
            name='label_de',
            field=models.CharField(default='', max_length=2048),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='questionentity',
            name='label_en',
            field=models.CharField(default='', max_length=2048),
            preserve_default=False,
        ),
    ]
