# Generated by Django 2.2rc1 on 2019-03-26 13:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0019_remove_null_true'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='option',
            options={'ordering': ('optionset__order', 'optionset__key', 'order', 'key'), 'verbose_name': 'Option', 'verbose_name_plural': 'Options'},
        ),
        migrations.AlterModelOptions(
            name='optionset',
            options={'ordering': ('uri',), 'verbose_name': 'Option set', 'verbose_name_plural': 'Option sets'},
        ),
        migrations.AlterField(
            model_name='option',
            name='optionset',
            field=models.ForeignKey(blank=True, help_text='The option set this option belongs to.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='options', to='options.OptionSet', verbose_name='Option set'),
        ),
    ]
