{% load socialaccount %}
{% load static %}

{% get_providers as socialaccount_providers %}

{% for provider in socialaccount_providers %}

{% if provider.id == "openid" %}
{% for brand in provider.get_brands %}
<li>
    <a title="{{brand.name}}"
        class="socialaccount_provider {{provider.id}} {{brand.id}}"
        href="{% provider_login_url provider.id openid=brand.openid_url process=process %}">
        {{brand.name}}
    </a>
</li>
{% endfor %}
{% endif %}

{% if provider.id == 'orcid' %}
<li class="socialaccount_provider_break">
    <a title="{{provider.name}}" class="socialaccount_provider {{provider.id}}"
        href="{% provider_login_url provider.id process=process scope=scope auth_params=auth_params %}">
        <img src="{% static 'accounts/img/orcid-signin.png' %}" alt="ORCID sign in" />
    </a>
</li>
{% else %}
<li>
    <a title="{{provider.name}}" class="socialaccount_provider {{provider.id}}"
        href="{% provider_login_url provider.id process=process scope=scope auth_params=auth_params %}">
        <span class="fa fa-{{provider.id}} fa-2x"></span>
    </a>
</li>
{% endif %}
{% endfor %}
