# Generated by Django 2.2.13 on 2020-08-31 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0031_related_name'),
        ('projects', '0036_remove_project_tasks'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='tasks',
            field=models.ManyToManyField(blank=True, help_text='The tasks that will be used for this project.', through='projects.Issue', to='tasks.Task', verbose_name='Tasks'),
        ),
    ]
