# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-06 15:09
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0031_meta'),
        ('projects', '0018_data_migration'),
        ('questions', '0016_data_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='attribute',
            name='unit',
        ),
        migrations.RemoveField(
            model_name='attribute',
            name='value_type',
        ),
    ]
