{% extends 'core/base.html' %}
{% load i18n %}
{% load static %}
{% load compress %}
{% load core_tags %}

{% block head %}
    {% compress css %}
    <link rel="stylesheet" href="{% static 'overlays/css/overlays.scss' %}" type="text/x-scss" />
    {% endcompress %}
    {% compress js %}
    <script type="text/javascript" src="{% static 'overlays/js/overlays.js' %}" ></script>
    {% endcompress %}
    <script>
        $(document).ready(function() { initOverlays('issue_send'); });
    </script>
{% endblock %}

{% block content %}

<div class="container">
    <div class="row">
        <form method="post" novalidate>
            {% csrf_token %}

            <div class="page col-md-9">
                <h1>{% trans 'Send task' %}</h1>

                <p>{% trans 'Sending a task will set the status to "in progress".' %}</p>

                <div id="issue-message">
                    {% include 'core/bootstrap_form_field.html' with field=form.subject %}
                    {% include 'core/bootstrap_form_field.html' with field=form.message %}

                    {% if mail_form.fields %}
                    {% include 'projects/issue_send_email.html'%}
                    {% endif %}
                </div>

                {% if integrations %}
                    {% include 'projects/issue_send_integrations.html'%}
                {% endif %}
            </div>
            <div class="sidebar col-md-3">
                {% include 'projects/issue_send_sidebar.html'%}
            </div>
        </form>
    </div>
</div>

{% render_lang_template 'projects/overlays/issue_send_issue_message' %}
{% render_lang_template 'projects/overlays/issue_send_issue_attachments' %}

{% endblock %}
