# Generated by Django 2.2.6 on 2019-10-11 12:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0017_role'),
    ]

    operations = [
        migrations.AlterField(
            model_name='role',
            name='manager',
            field=models.ManyToManyField(blank=True, help_text='The sites for which this user is manager.', related_name='managers', to='sites.Site', verbose_name='Manager'),
        ),
        migrations.AlterField(
            model_name='role',
            name='member',
            field=models.ManyToManyField(blank=True, help_text='The sites for which this user is a member.', related_name='members', to='sites.Site', verbose_name='Member'),
        ),
    ]
