# Generated by Django 2.2.16 on 2021-01-22 17:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0054_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='catalog',
            name='locked',
            field=models.BooleanField(default=False, help_text="Designates whether this catalog (and it's sections, question sets and questions) can be changed.", verbose_name='Locked'),
        ),
        migrations.AddField(
            model_name='question',
            name='locked',
            field=models.BooleanField(default=False, help_text='Designates whether this question can be changed.', verbose_name='Locked'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='locked',
            field=models.BooleanField(default=False, help_text="Designates whether this questionset (and it's questions) can be changed.", verbose_name='Locked'),
        ),
        migrations.AddField(
            model_name='section',
            name='locked',
            field=models.BooleanField(default=False, help_text="Designates whether this section (and it's question sets and questions) can be changed.", verbose_name='Locked'),
        ),
    ]
