{% load i18n %}

    <li>
        <a href="{% url 'account_email' %}">{% trans 'Update email' %}</a>
    </li>
    <li>
        <a href="{% url 'account_change_password' %}">{% trans 'Change password' %}</a>
    </li>
