{% load i18n %}

    <i class="fa fa-lock text-muted" ng-show="questionset.locked || section.locked || service.catalog.locked"></i>
    <i class="fa fa-lock text-danger" ng-show="question.locked"></i>

    <a href="" class="fa fa-pencil"
        title="{% trans 'Update question' %}"
        ng-click="service.openFormModal('questions', question)">
    </a>

    <a href="" class="fa fa-copy"
        title="{% trans 'Copy question' %}"
        ng-click="service.openFormModal('questions', question, false, true)">
    </a>

    <a href="{$ question.xml_url $}" class="fa fa-download"
        title="{% trans 'Export question as XML' %}"
        target="blank">
    </a>

    <a href="" class="fa fa-trash"
        title="{% trans 'Delete question' %}"
        ng-click="service.openDeleteModal('questions', question)">
    </a>
