# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-31 12:40
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0020_data_migration'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='value',
            options={'ordering': ('attribute', 'set_index', 'collection_index'), 'permissions': (('view_value', 'Can view value'),), 'verbose_name': 'Value', 'verbose_name_plural': 'Values'},
        ),
    ]
