<div class="overlay" id="issue-attachments-overlay"
    data-title="Viste"
    data-placement="left auto">

    Qui puoi allegare al tuo messaggio una vista adatta nel formato desiderato.

    {% include 'overlays/buttons.html'%}
</div>
