# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-01-27 15:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('views', '0004_refactoring'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='view',
            options={'ordering': ('key',), 'verbose_name': 'View', 'verbose_name_plural': 'Views'},
        ),
        migrations.AlterField(
            model_name='view',
            name='comment',
            field=models.TextField(blank=True, help_text='Additional information about this view.', null=True, verbose_name='Comment'),
        ),
        migrations.AlterField(
            model_name='view',
            name='key',
            field=models.SlugField(blank=True, help_text='The internal identifier of this view. The URI will be generated from this key.', max_length=128, null=True, verbose_name='Key'),
        ),
        migrations.AlterField(
            model_name='view',
            name='uri',
            field=models.URLField(blank=True, help_text='The Uniform Resource Identifier of this view (auto-generated).', max_length=640, null=True, verbose_name='URI'),
        ),
        migrations.AlterField(
            model_name='view',
            name='uri_prefix',
            field=models.URLField(blank=True, help_text='The prefix for the URI of this view.', max_length=256, null=True, verbose_name='URI Prefix'),
        ),
    ]
