@font-face {
    font-family: "DroidSans";
    src: url(static('core/fonts/DroidSans.ttf'));
}
@font-face {
    font-family: "DroidSans";
    src: url(static('core/fonts/DroidSans-Bold.ttf'));
    font-weight: bold;
}
@font-face {
    font-family: "DroidSans-Mono";
    src: url(static('core/fonts/DroidSansMono.ttf'));
}
@font-face {
    font-family: "DroidSerif";
    src: url(static('core/fonts/DroidSerif.ttf'));
}
@font-face {
    font-family: "DroidSerif";
    src: url(static('core/fonts/DroidSerif-Bold.ttf'));
    font-weight: bold;
}
@font-face {
    font-family: "DroidSerif";
    src: url(static('core/fonts/DroidSerif-Italic.ttf'));
    font-style: italic;
}
@font-face {
    font-family: "DroidSerif";
    src: url(static('core/fonts/DroidSerif-BoldItalic.ttf'));
    font-style: italic;
    font-weight: bold;
}

body {
    font-family: DroidSans, sans;
}
h1, h2, h3, h4, h5, h6 {
    font-family: DroidSerif, serif;
}

a.fa {
    text-decoration: none !important;
}
