{% extends 'core/export.html' %}
{% load i18n %}

{% block body %}

    <h1>{% trans 'Views' %}</h1>

    <ul>

    {% for view in views %}

    <li>

    <p>
        <strong>{% trans 'URI' %}:</strong> {{ view.uri }}
    </p>

    {% if task.comment %}

    <p>
        <strong>{% trans 'Comment' %}:</strong> {{ view.comment }}
    </p>

    {% endif %}

    <p>
        <strong>{% trans 'Title' %}:</strong> {{ view.title }}
    </p>

    <p>
        <strong>{% trans 'Help text' %}:</strong> {{ view.help }}
    </p>

    <p>
        <strong>{% trans 'Template' %}:</strong>
    </p>

    <pre>{{ view.template }}</pre>

    </li>

    {% endfor %}

    </ul>

{% endblock %}
