<div class="overlay" id="project-memberships-overlay"
    data-title="Members"
    data-placement="top auto">

    Here you can see who can access the project and invite additional members.  The rights of the use can be managed by the roles. Members can be removed with the cross symbol.

    {% include 'overlays/buttons.html'%}
</div>
