{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h2>{% trans "Delete profile" %}</h2>

    <p>
        {% trans "Your profile was successfully removed." %}
    </p>

{% endblock %}
