# Generated by Django 2.2.18 on 2021-02-09 12:09

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0047_continuation'),
    ]

    operations = [
        migrations.AlterField(
            model_name='membership',
            name='project',
            field=models.ForeignKey(help_text='The project for this membership.', on_delete=django.db.models.deletion.CASCADE, related_name='memberships', to='projects.Project', verbose_name='Project'),
        ),
        migrations.AlterField(
            model_name='membership',
            name='user',
            field=models.ForeignKey(help_text='The user for this membership.', on_delete=django.db.models.deletion.CASCADE, related_name='memberships', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AlterField(
            model_name='project',
            name='user',
            field=models.ManyToManyField(help_text='The list of users for this project.', related_name='projects', through='projects.Membership', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
    ]
