<h2>Benvenuti a RDMO</h2>

<p>
    L'obiettivo del progetto RDMO &egrave; fornire un'applicazione web per aiutare la pianificazione, l'implementazione e l'amministrazione dei dati in un progetto scientifico. In aggiunta, le informazioni raccolte possono essere stampate in formato testuale per essere inviate ai finanziatori.
</p>

<p>
    Questo &egrave; un prototipo del software, per soli scopi dimostrativi.
</p>

<p>
    Maggiori informazioni sul progetto sono disponibili su <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
</p>
