# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2019-03-13 11:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0041_data_migration'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attribute',
            name='comment',
            field=models.TextField(blank=True, help_text='Additional information about this attribute.', verbose_name='Comment'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='key',
            field=models.SlugField(blank=True, help_text='The internal identifier of this attribute.', max_length=128, verbose_name='Key'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='uri',
            field=models.URLField(blank=True, help_text='The Uniform Resource Identifier of this attribute (auto-generated).', max_length=640, verbose_name='URI'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='uri_prefix',
            field=models.URLField(blank=True, help_text='The prefix for the URI of this attribute.', max_length=256, verbose_name='URI Prefix'),
        ),
    ]
