# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-03 13:27
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0027_meta'),
    ]

    operations = [
        migrations.RenameField(
            model_name='attributeentity',
            old_name='label',
            new_name='path',
        ),
    ]
