{% load i18n %}

{% if settings.PROJECT_QUESTIONS_AUTOSAVE %}
<p class="help-block">
    {% trans 'Using the navigation will save your input.' %}
</p>
{% else %}
<p class="help-block">
    {% trans 'Please note that using the navigation will discard any unsaved input.' %}
</p>
{% endif %}

<p class="help-block">
{% blocktrans %}
Entries with <i class="fa fa-question-circle-o small" aria-hidden="true"></i> might be skipped based on your input.
{% endblocktrans %}
</p>
