{% load i18n %}

    <p class="text-muted">
        {% blocktrans trimmed %}
        Views are created using the answers given in the project and can then be exported in various formats. Initially, all views are empty. Please answer some questions by visiting <strong>Answer Questions</strong> (at the top of the sidebar).
        {% endblocktrans %}
    </p>
