<div class="overlay" id="project-catalog-overlay"
    data-title="Catalog"
    data-placement="bottom">

    With the right permissions, you can change the selection of the question catalog here.

    {% include 'overlays/buttons.html'%}
</div>
