# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2019-03-13 11:22
from __future__ import unicode_literals

from django.db import migrations


def run_data_migration(apps, schema_editor):
    Option = apps.get_model('options', 'Option')

    for option in Option.objects.all():
        if option.optionset == None:
            option.delete()


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0020_django2'),
    ]

    operations = [
        migrations.RunPython(run_data_migration),
    ]
