<div class="overlay" id="project-issues-overlay"
    data-title="Tasks"
    data-placement="bottom auto">

    Tasks are automatically generated from the answers you give in the questionnaires. On the page of each task you can see which of your answers lead to the activation of the task. You can also change the status of your to-do tasks with the pencil icon when you have started or finished a task. With the paper airplane icon you can send an e-mail and attach a view in the desired format, if necessary. At the beginning, the overview of the tasks is empty.

    {% include 'overlays/buttons.html'%}
</div>
