@import 'core/css/variables';

.projects-table {
    margin-bottom: 0;
}

.projects-search {
    position: relative;

    .projects-search-reset {
        display: block;
        position: absolute;
        top: 7px;
        right: 7px;
        z-index: 1020;

        opacity: 0.8;
        line-height: 20px;
        font-size: 14px;

        margin-left: 2px;
    }
}
