# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2019-03-13 11:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0024_data_migration'),
    ]

    operations = [
        migrations.AlterField(
            model_name='value',
            name='text',
            field=models.TextField(blank=True, help_text='The string stored for this value.', verbose_name='Text'),
        ),
    ]
