<div class="overlay" id="project-memberships-overlay"
    data-title="Membri"
    data-placement="top auto">

    Qui puoi vedere chi può accedere al progetto e invitare altri membri.  I diritti di utilizzo possono essere gestiti dai ruoli. I membri possono essere rimossi con il simbolo della croce.

    {% include 'overlays/buttons.html'%}
</div>
