# Generated by Django 2.2.13 on 2020-09-25 09:34

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0039_integrationoption_secret'),
    ]

    operations = [
        migrations.CreateModel(
            name='IssueResource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField(help_text='The URL of this issue resource.', verbose_name='URL')),
                ('integration', models.ForeignKey(help_text='The integration for this issue resource.', on_delete=django.db.models.deletion.CASCADE, related_name='resources', to='projects.Integration', verbose_name='Integration')),
                ('issue', models.ForeignKey(help_text='The issue for this issue resource.', on_delete=django.db.models.deletion.CASCADE, related_name='resources', to='projects.Issue', verbose_name='Issue')),
            ],
            options={
                'verbose_name': 'Issue resource',
                'verbose_name_plural': 'Issue resources',
                'ordering': ('issue__project__title', 'issue'),
            },
        ),
    ]
