<div class="overlay" id="project-questions-overlay"
    data-title="Fragen beantworten"
    data-placement="left auto">

    Klicken Sie an dieser Stelle "Fragen beantworten", um zum Interview zum ausgewählten
    Fragenkatalog zu gelangen. Ihre Antworten werden dazu verwendet individuelle Aufgaben
    für Sie zu erstellen, die Sie in der Aufgabenübersicht finden sowie um vorgefertigte
    Vorlagen auszufüllen, die Sie für die weitere Verwendung exportieren können.

    {% include 'overlays/buttons.html'%}
</div>
