{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Logout" %}</h1>

    <p>
        {% trans 'Are you sure you want to sign out?' %}
    </p>

    <form method="post" action="{% url 'account_logout' %}">
        {% csrf_token %}

        {% if redirect_field_value %}
        <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
        {% endif %}

        <input type="submit" class="btn btn-primary" value="{% trans 'Logout' %}" />
    </form>

{% endblock %}
