<div class="overlay" id="project-memberships-overlay"
    data-title="Mitgliedschaften"
    data-placement="top auto">

    Hier können Sie sehen, wer auf das Projekt zugreifen kann und weitere Mitglieder einladen. Über die Rollen können Sie verwalten, welche Rechte die Nutzenden haben. Mit dem Kreuzsymbol können Mitgliedschaften entfernt werden.

    {% include 'overlays/buttons.html'%}
</div>
