<div class="overlay" id="project-questions-overlay"
    data-title="Répondez aux questions"
    data-placement="left auto">

    Cliquez sur "Répondre aux questions" à ce stade pour accéder à l'interview du questionnaire sélectionné.
    Vos réponses seront utilisées pour créer des tâches individuelles pour vous, que vous trouverez dans
    l'aperçu des tâches, ainsi que pour remplir des modèles prêts à l'emploi que vous pouvez exporter pour une utilisation ultérieure.

    {% include 'overlays/buttons.html'%}
</div>
