<div class="overlay" id="project-questions-overlay"
    data-title="Answer questions"
    data-placement="left auto">

    Click "Answer questions" at this point to go to the interview for the selected questionnaire.
    Your answers will be used to create individual tasks for you, which you will find in
    the task overview, as well as to fill in ready-made templates that you can export for further use.

    {% include 'overlays/buttons.html'%}
</div>
