{% load i18n %}

    <p class="text-muted">
        {% blocktrans trimmed %}
        Tasks are generated automatically from the answers given in the project. On the page of each task you can see which of your answers lead to the activation of the task.
        {% endblocktrans %}
    </p>
