# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-11-29 11:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0022_move_attribute_to_attributeentity'),
    ]

    operations = [
        migrations.AlterField(
            model_name='value',
            name='value_type',
            field=models.CharField(choices=[('text', 'Text'), ('url', 'URL'), ('integer', 'Integer'), ('float', 'Float'), ('boolean', 'Boolean'), ('datetime', 'Datetime'), ('option', 'Option')], help_text='Type of this value.', max_length=8, verbose_name='Value type'),
        ),
    ]
