# Generated by Django 2.2.16 on 2021-01-21 10:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0046_parent_cascade'),
    ]

    operations = [
        migrations.AddField(
            model_name='attribute',
            name='locked',
            field=models.BooleanField(default=False, help_text="Designates whether this attribute (and it\'s descendants) can be changed.", verbose_name='Locked'),
        ),
    ]
