{% load i18n %}

<h2>{% trans 'Overview' %}</h2>

{% include 'projects/project_questions_overview.html' %}

<h2>{% trans 'Progress' %}</h2>

{% include 'projects/project_questions_progress.html' %}
{% include 'projects/project_questions_buttons.html' with sidebar=True %}

<h2>{% trans 'Navigation' %}</h2>

{% include 'projects/project_questions_navigation.html' %}
