{% load i18n %}

    <span ng-show="service.isDefaultValue(question, value)" class="badge badge-default-value"
          title="{% trans 'This is a default answer that can be customized.' %}">
        {% trans 'Default' %}
    </span>
