# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-03 13:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0009_data_migration'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='option',
            options={'ordering': ('optionset__order', 'order'), 'verbose_name': 'Option', 'verbose_name_plural': 'Options'},
        ),
        migrations.AlterField(
            model_name='option',
            name='path',
            field=models.SlugField(blank=True, help_text='The path part of the URI for this option (auto-generated).', max_length=512, null=True, verbose_name='Path'),
        ),
    ]
