# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-04 14:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0011_permissions'),
    ]

    operations = [
        migrations.AlterField(
            model_name='option',
            name='comment',
            field=models.TextField(blank=True, help_text='Additional internal information about this option.', null=True, verbose_name='Comment'),
        ),
        migrations.AlterField(
            model_name='option',
            name='key',
            field=models.SlugField(blank=True, help_text='The internal identifier of this option.', max_length=128, null=True, verbose_name='Key'),
        ),
        migrations.AlterField(
            model_name='option',
            name='order',
            field=models.IntegerField(default=0, help_text='Position in lists.', verbose_name='Order'),
        ),
        migrations.AlterField(
            model_name='optionset',
            name='comment',
            field=models.TextField(blank=True, help_text='Additional internal information about this option set.', null=True, verbose_name='Comment'),
        ),
        migrations.AlterField(
            model_name='optionset',
            name='key',
            field=models.SlugField(blank=True, help_text='The internal identifier of this option set.', max_length=128, null=True, verbose_name='Key'),
        ),
    ]
