# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-21 13:56
from __future__ import unicode_literals

import django.contrib.auth.models
from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0008_alter_user_username_max_length'),
        ('accounts', '0008_related_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProxyUser',
            fields=[
            ],
            options={
                'default_permissions': (),
                'proxy': True,
                'permissions': (('view_user', 'Can view user'),),
            },
            bases=(settings.AUTH_USER_MODEL,),
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
    ]
