# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-14 15:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0028_rename_question'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='maximum',
            field=models.FloatField(blank=True, help_text='Maximum value for this question.', null=True, verbose_name='Maximum'),
        ),
        migrations.AddField(
            model_name='question',
            name='minimum',
            field=models.FloatField(blank=True, help_text='Minimal value for this question.', null=True, verbose_name='Minimum'),
        ),
        migrations.AddField(
            model_name='question',
            name='step',
            field=models.FloatField(blank=True, help_text='Step in which the value for this question can be incremented/decremented.', null=True, verbose_name='Step'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_de',
            field=models.CharField(blank=True, help_text='German name displayed for this question (e.g. Projekt).', max_length=256, verbose_name='Name (de)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_en',
            field=models.CharField(blank=True, help_text='English name displayed for this question (e.g. project).', max_length=256, verbose_name='Name (en)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_plural_de',
            field=models.CharField(blank=True, help_text='German plural name displayed for this question (e.g. Projekte).', max_length=256, verbose_name='Plural name (de)'),
        ),
        migrations.AddField(
            model_name='question',
            name='verbose_name_plural_en',
            field=models.CharField(blank=True, help_text='English plural name displayed for this question (e.g. projects).', max_length=256, verbose_name='Plural name (en)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_de',
            field=models.CharField(blank=True, help_text='German name displayed for this question (e.g. Projekt).', max_length=256, verbose_name='Name (de)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_en',
            field=models.CharField(blank=True, help_text='English name displayed for this question (e.g. project).', max_length=256, verbose_name='Name (en)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_plural_de',
            field=models.CharField(blank=True, help_text='German plural name displayed for this question (e.g. Projekte).', max_length=256, verbose_name='Plural name (de)'),
        ),
        migrations.AddField(
            model_name='questionset',
            name='verbose_name_plural_en',
            field=models.CharField(blank=True, help_text='English plural name displayed for this question (e.g. projects).', max_length=256, verbose_name='Plural name (en)'),
        ),
    ]
