{% extends 'core/page.html' %}

{% load i18n %}
{% load core_tags %}

{% block page %}

    <h2>{% trans 'No catalog configured' %}</h2>

    <p>
        {% trans "The project does appear not to have a question catalog. Please update your project." %}
    </p>

    <p>
        {% trans "You will be redirected shortly." %}
    </p>

    <script type="text/javascript">
        window.setTimeout(function(){
            window.location.replace('{% url 'project_update' project.id %}');
        }, 5000);
    </script>

{% endblock%}
