{% load i18n %}

    <i class="fa fa-lock text-muted" ng-show="service.catalog.locked"></i>
    <i class="fa fa-lock text-danger" ng-show="section.locked"></i>

    <a href="" class="fa fa-plus"
        title="{% trans 'Add question set' %}"
        ng-click="service.openFormModal('questionsets', section, true)">
    </a>

    <a href="" class="fa fa-pencil"
        title="{% trans 'Update section' %}"
        ng-click="service.openFormModal('sections', section)">
    </a>

    <a href="" class="fa fa-copy"
        title="{% trans 'Copy section' %}"
        ng-click="service.openFormModal('sections', section, false, true)">
    </a>

    <a href="{$ section.xml_url $}" class="fa fa-download"
        title="{% trans 'Export section as XML' %}"
        target="blank">
    </a>

    <a href="" class="fa fa-trash"
        title="{% trans 'Delete section' %}"
        ng-click="service.openDeleteModal('sections', section)">
    </a>
