/* colors */

$text-color: #101F70;
$variant-color: #666;
$background-color: #fefefe;

$headline-color: #101F70;
$headline-background-color: transparent;

$link-color: #337ab7;
$link-color-visited: #337ab7;
$link-color-hover: #337ab7;
$link-color-focus: #337ab7;

$navigation-color: #9d9d9d;
$navigation-background-color: #101F70;
$navigation-hover-color: #fff;
$navigation-hover-background-color: rgba(255, 255, 255, 0.1);
$navigation-dropdown-color: #333;
$navigation-dropdown-hover-color: #262626;
$navigation-dropdown-hover-background-color: #f5f5f5;

$footer-color: #999;
$footer-link-color: #999;
$footer-background-color: #001;

$danger-color: #a94442;
$success-color: #5cb85c;
$modal-border-color: #e5e5e5;

/* transitions */

$image-transition: opacity 2s ease-in-out;

/* responsive thresholds */

$screen-xs-max: 768px;
$screen-sm-max: 992px;
$screen-md-max: 1200px;
