<div class="overlay" id="project-views-overlay"
    data-title="Viste"
    data-placement="bottom auto">

    Le viste sono modelli di moduli/documenti. Le viste sono compilate automaticamente in base alle risposte date nel questionario e possono poi essere esportate e inviate in diversi formati. All'inizio, tutte le viste sono vuote. Affinché i modelli siano compilati completamente, è necessario rispondere a tutte le domande pertinenti. Le risposte che vengono utilizzate in diversi modelli vengono automaticamente trasferite a tutti i cataloghi di domande e alle viste.

    {% include 'overlays/buttons.html'%}
</div>
