# Generated by Django 2.2.18 on 2021-05-27 11:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0061_question_width'),
    ]

    operations = [
        migrations.AlterField(
            model_name='questionset',
            name='attribute',
            field=models.ForeignKey(blank=True, help_text='The attribute this question set belongs to.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='questionsets', to='domain.Attribute', verbose_name='Attribute'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='comment',
            field=models.TextField(blank=True, help_text='Additional internal information about this question set.', verbose_name='Comment'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='conditions',
            field=models.ManyToManyField(blank=True, help_text='List of conditions evaluated for this question set.', related_name='questionsets', to='conditions.Condition', verbose_name='Conditions'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang1',
            field=models.TextField(blank=True, help_text='The help text for this question set in the primary language.', verbose_name='Help (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang2',
            field=models.TextField(blank=True, help_text='The help text for this question set in the secondary language.', verbose_name='Help (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang3',
            field=models.TextField(blank=True, help_text='The help text for this question set in the tertiary language.', verbose_name='Help (tertiary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang4',
            field=models.TextField(blank=True, help_text='The help text for this question set in the quaternary language.', verbose_name='Help (quaternary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='help_lang5',
            field=models.TextField(blank=True, help_text='The help text for this question set in the quinary language.', verbose_name='Help (quinary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='is_collection',
            field=models.BooleanField(default=False, help_text='Designates whether this question set is a collection.', verbose_name='is collection'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='key',
            field=models.SlugField(blank=True, help_text='The internal identifier of this question set.', max_length=128, verbose_name='Key'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='locked',
            field=models.BooleanField(default=False, help_text="Designates whether this question set (and it's questions) can be changed.", verbose_name='Locked'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='order',
            field=models.IntegerField(default=0, help_text='The position of this question set in lists.', verbose_name='Order'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='path',
            field=models.CharField(blank=True, help_text='The path part of the URI of this question set (auto-generated).', max_length=512, verbose_name='Path'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='section',
            field=models.ForeignKey(help_text='The section this question set belongs to.', on_delete=django.db.models.deletion.CASCADE, related_name='questionsets', to='questions.Section', verbose_name='Section'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang1',
            field=models.CharField(blank=True, help_text='The title for this question set in the primary language.', max_length=256, verbose_name='Title (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang2',
            field=models.CharField(blank=True, help_text='The title for this question set in the secondary language.', max_length=256, verbose_name='Title (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang3',
            field=models.CharField(blank=True, help_text='The title for this question set in the tertiary language.', max_length=256, verbose_name='Title (tertiary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang4',
            field=models.CharField(blank=True, help_text='The title for this question set in the quaternary language.', max_length=256, verbose_name='Title (quaternary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='title_lang5',
            field=models.CharField(blank=True, help_text='The title for this question set in the quinary language.', max_length=256, verbose_name='Title (quinary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='uri',
            field=models.URLField(blank=True, help_text='The Uniform Resource Identifier of this question set (auto-generated).', max_length=640, verbose_name='URI'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='uri_prefix',
            field=models.URLField(help_text='The prefix for the URI of this question set.', max_length=256, verbose_name='URI Prefix'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang1',
            field=models.CharField(blank=True, help_text='The name displayed for this question set in the primary language.', max_length=256, verbose_name='Name (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang2',
            field=models.CharField(blank=True, help_text='The name displayed for this question set in the secondary language.', max_length=256, verbose_name='Name (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang3',
            field=models.CharField(blank=True, help_text='The name displayed for this question set in the tertiary language.', max_length=256, verbose_name='Name (tertiary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang4',
            field=models.CharField(blank=True, help_text='The name displayed for this question set in the quaternary language.', max_length=256, verbose_name='Name (quaternary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_lang5',
            field=models.CharField(blank=True, help_text='The name displayed for this question set in the quinary language.', max_length=256, verbose_name='Name (quinary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang1',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question set in the primary language.', max_length=256, verbose_name='Plural name (primary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang2',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question set in the secondary language.', max_length=256, verbose_name='Plural name (secondary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang3',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question set in the tertiary language.', max_length=256, verbose_name='Plural name (tertiary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang4',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question set in the quaternary language.', max_length=256, verbose_name='Plural name (quaternary)'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='verbose_name_plural_lang5',
            field=models.CharField(blank=True, help_text='The plural name displayed for this question set in the quinary language.', max_length=256, verbose_name='Plural name (quinary)'),
        ),
    ]
