{% load static %}
{% load core_tags %}
{% load i18n %}

<div class="text-center">
    <img class="rdmo-logo" src="{% static 'core/img/rdmo-logo.svg' %}" alt="{% trans 'RDMO Logo' %}" />

    <h1>Research data management organiser</h1>

    <h4>Versione {% version %}</h4>
</div>

<div class="text-justify">
    <p>
    	RDMO consente alle istituzioni e ai singoli ricercatori la pianificazione della gestione dei dati della ricerca. RDMO assembla tutte le informazioni riguardanti la pianificazione e la gestione
	dei dati durante l'intera vita dei dati della ricerca.
    </p>

    <p>
	RDMO pu&ograve; essere usata in progetti grossi e piccoli. Nella prossima fase del progetto, iniziata nel Novembre 2017, RDMO sar&agrave; esteso e i partner del progetto
	AIP, FHP, biblioteca KIT collaboreranno con gli utenti RDMO per migliorarne l'utilizzo. Questo strumento sar&agrave; esteso, migliorando l'implementazione dei ruoli e dell'interfacciamento
	con le infrastrutture istituzionali, ad es. repositories, sistemi di ticketing, e infrastruttura di autenticazione e autorizzazione. Verranno anche scritti tutorial e documentazione, e
	organizzati workshop per utenti e sviluppatori.
    </p>

    <p>
    	Maggiori informazioni su RDMO sono disponibili su <a href="https://rdmorganiser.github.io">rdmorganiser.github.io</a>.
    </p>
</div>
