# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-16 14:12
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0035_remove_is_collection_and_parent_collection'),
        ('questions', '0030_data_migration')
    ]

    operations = [
        migrations.RemoveField(
            model_name='range',
            name='attribute',
        ),
        migrations.RemoveField(
            model_name='verbosename',
            name='attribute_entity',
        ),
        migrations.DeleteModel(
            name='Range',
        ),
        migrations.DeleteModel(
            name='VerboseName',
        ),
    ]
