# Generated by Django 2.2.16 on 2020-10-19 15:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0018_blank_fields'),
    ]

    operations = [
        migrations.DeleteModel(
            name='ProxyUser',
        ),
    ]
