# Generated by Django 2.2.16 on 2021-01-22 19:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('options', '0025_optionset_provider_key'),
    ]

    operations = [
        migrations.AddField(
            model_name='option',
            name='locked',
            field=models.BooleanField(default=False, help_text='Designates whether this option can be changed.', verbose_name='Locked'),
        ),
        migrations.AddField(
            model_name='optionset',
            name='locked',
            field=models.BooleanField(default=False, help_text="Designates whether this option set (and it's options) can be changed.", verbose_name='Locked'),
        ),
    ]
