{% load i18n %}

<div class="popover-buttons">
    <button type="button" class="btn btn-sm popover-dismiss" title="Dismiss all tips on this page">{% trans 'Dismiss' %}</button>
    <button type="button" class="btn btn-primary btn-sm popover-next">{% trans 'Next tip' %}</button>
</div>
