{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h2>
        {% trans "Verify your e-mail address" %}
    </h2>

    <p>
        {% blocktrans %}We have sent an e-mail to you for verification. Follow the link provided to finalize the signup process. Please contact us if you do not receive it within a few minutes.{% endblocktrans %}
    </p>

{% endblock %}
