<div class="row">
    <div class="footer-col col-md-4">
        <h4>À propos de RDMO</h4>
        <p>
            RDMO soutient la planification, l'organisation et la mise en œuvre systématiques de la gestion des données tout au long d'un projet de recherche.
        </p>
        <p>
            RDMO est un logiciel open source et disponible à l'adresse <a href="https://github.com/rdmorganiser/rdmo">https://github.com/rdmorganiser/rdmo</a>.
        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Contact</h4>
        <p>

        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Mentions légales et protection des données</h4>
        <p>

        </p>
    </div>
</div>
