<div class="overlay" id="issue-message-overlay"
    data-title="Message"
    data-placement="bottom">

    Les tâches vous demandent souvent de contacter un autre service. Vous trouverez ici un message prêt à l'emploi avec les personnes de contact concernées comme destinataires, que vous pouvez envoyer ici comme un e-mail.

    {% include 'overlays/buttons.html'%}
</div>
