<div class="overlay" id="import-project-overlay"
    data-title="Importa"
    data-placement="left auto">

    Se hai già creato ed esportato un progetto in RDMO e vuoi aggiungerlo, puoi importare un progetto esistente qui.

    {% include 'overlays/buttons.html'%}
</div>
