<div class="overlay" id="project-catalog-overlay"
    data-title="Katalog"
    data-placement="bottom">

    Sofern sie berechtigt sind, können Sie hier die Auswahl des Fragenkatalogs ändern.

    {% include 'overlays/buttons.html'%}
</div>
