# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-09-23 14:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0003_meta'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='snapshot',
            options={'ordering': ('project', '-created'), 'verbose_name': 'Snapshot', 'verbose_name_plural': 'Snapshots'},
        ),
        migrations.RemoveField(
            model_name='project',
            name='current_snapshot',
        ),
    ]
