{% load i18n %}

<h2 id="issue-attachments">{% trans 'Attachments' %}</h2>

{% include 'core/bootstrap_form_field.html' with field=form.attachments_answers %}
{% include 'core/bootstrap_form_field.html' with field=form.attachments_views %}
{% include 'core/bootstrap_form_field.html' with field=form.attachments_files %}
{% include 'core/bootstrap_form_field.html' with field=form.attachments_snapshot %}
{% include 'core/bootstrap_form_field.html' with field=form.attachments_format %}
