# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-16 10:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0018_data_migration'),
    ]

    operations = [
        migrations.AlterField(
            model_name='value',
            name='value_type',
            field=models.CharField(choices=[(b'text', 'Text'), (b'url', 'URL'), (b'integer', 'Integer'), (b'float', 'Float'), (b'boolean', 'Boolean'), (b'datetime', 'Datetime'), (b'option', 'Option')], help_text='Type of this value.', max_length=8, verbose_name='Value type'),
        ),
    ]
