<div class="row">
    <div class="footer-col col-md-4">
        <h4>About RDMO</h4>
        <p>
            The Research Data Management Organiser supports the systematic planning, organisation and implementation of the data management throughout the course of a research project.
        </p>
        <p>
            RDMO is open source software and available at <a href="https://github.com/rdmorganiser/rdmo">https://github.com/rdmorganiser/rdmo</a>
        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Contact</h4>
        <p>

        </p>
    </div>
    <div class="footer-col col-md-4">
        <h4>Imprint and data protection</h4>
        <p>

        </p>
    </div>
</div>
