# Generated by Django 2.2.18 on 2021-04-20 13:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0058_question_default_option'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='default_external_id',
            field=models.CharField(blank=True, help_text='The default external id for this question. To be used with dynamic optionsets.', max_length=256, verbose_name='Default external id'),
        ),
    ]
