<div class="overlay" id="import-project-overlay"
    data-title="Vorhandenes Projekt importieren"
    data-placement="left auto">

    Sollten Sie bereits ein Projekt in RDMO angelegt und exportiert haben
    und möchten es Ihrer Projektliste an dieser Stelle hinzufügen,
    so können sie hier ein vorhandenes Projekt importieren.

    {% include 'overlays/buttons.html'%}
</div>
