# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-10-25 11:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0020_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='attribute',
            name='optionsets',
            field=models.ManyToManyField(blank=True, to='options.OptionSet'),
        ),
    ]
