<!DOCTYPE html>
<html>
<head>
    {% include 'core/base_head.html' %}
    {% block head %}{% endblock %}
</head>

<body {% block bodyattr %}{% endblock %}>

<!-- navigation -->
{% include 'core/base_navigation.html' %}
<!-- end navigation -->

<!-- content -->
<div class="content">
    {% block content %}{% endblock %}
</div>
<!-- end content -->

<!-- footer -->
{% include 'core/base_footer.html' %}
<!-- end footer -->

{% if not debug %}
<!-- analytics -->
    {% include 'core/base_analytics.html' %}

<!-- end analytics -->
{% endif %}

{% block extra_body %}{% endblock %}

</body>
</html>
