{% extends 'core/page.html' %}
{% load i18n %}
{% load account %}

{% block page %}

    <h1>{% trans "Confirm E-mail Address" %}</h1>

    {% if confirmation %}

    {% user_display confirmation.email_address.user as user_display %}

    <p>
        {% blocktrans trimmed with confirmation.email_address.email as email %}
        Please confirm that <a href="mailto:{{ email }}">{{ email }}</a> is an e-mail address for user <strong>{{ user_display }}</strong>.
        {% endblocktrans %}
    </p>

    <form method="post" action="{% url 'account_confirm_email' confirmation.key %}">
        {% csrf_token %}
        <input type="submit" class="btn btn-primary" value="{% trans 'Confirm' %}" />
    </form>

    {% else %}

    {% url 'account_email' as email_url %}

    <p>
        {% blocktrans trimmed %}
        This e-mail confirmation link expired or is invalid. Please <a href="{{ email_url }}">issue a new e-mail confirmation request</a>.
        {% endblocktrans %}
    </p>

    {% endif %}

{% endblock %}