# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-25 14:23
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('projects', '0014_remove_owner'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='membership',
            options={'ordering': ('project__title',), 'permissions': (('view_membership', 'Can view membership'),), 'verbose_name': 'Membership', 'verbose_name_plural': 'Memberships'},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'ordering': ('title',), 'permissions': (('view_project', 'Can view project'),), 'verbose_name': 'Project', 'verbose_name_plural': 'Projects'},
        ),
        migrations.AlterModelOptions(
            name='snapshot',
            options={'ordering': ('project', '-created'), 'permissions': (('view_snapshot', 'Can view snapshot'),), 'verbose_name': 'Snapshot', 'verbose_name_plural': 'Snapshots'},
        ),
        migrations.AlterModelOptions(
            name='value',
            options={'permissions': (('view_value', 'Can view value'),), 'verbose_name': 'Value', 'verbose_name_plural': 'Values'},
        ),
    ]
