{% load i18n %}
{% load core_tags %}

    <p>
        {% trans 'Thank you for filling out the questionnaire.' %}
    </p>

    <p>
        <a href="{% url 'project_answers' project.id %}">{% trans 'View answers' %}</a>
    </p>

    <p>
        <a href="{% url 'project' project.id %}">{% trans 'Back to project overview' %}</a>
    </p>
