<div class="overlay" id="export-project-overlay"
    data-title="Exporter"
    data-placement="left auto">

    Vous pouvez exporter votre projet ici si vous souhaitez l'importer dans RDMO à une date ultérieure ou dans une autre instance de RDMO.

    {% include 'overlays/buttons.html'%}
</div>
