# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-08-03 14:30
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('domain', '0014_is_attribute'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='attributeentity',
            options={'ordering': ('label',), 'verbose_name': 'AttributeEntity', 'verbose_name_plural': 'AttributeEntities'},
        ),
        migrations.RenameField(
            model_name='attributeentity',
            old_name='full_title',
            new_name='label',
        ),
    ]
