<div class="overlay" id="projects-table-overlay"
    data-title="My Projects"
    data-placement="bottom">

    Here you will find all your self-created projects, as well as projects to which you have been added.
    At first, this overview will be empty. The specified role (owner, manager, author, guest) defines
    your access restriction to the project. You can edit or delete the projects with the help
    of the symbols on the right in the respective line.

    {% include 'overlays/buttons.html'%}
</div>
