<div class="overlay" id="issue-attachments-overlay"
    data-title="Vues"
    data-placement="left auto">

    Ici, vous pouvez joindre à votre message une vue appropriée dans le format souhaité.

    {% include 'overlays/buttons.html'%}
</div>
