{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Change password" %}</h1>

    <p>
        {% trans "Please enter your old password, and then enter your new password twice so we can verify you typed it in correctly." %}
    </p>

    <form method="post" action="{% url 'account_change_password' %}">
        {% csrf_token %}

        {% include 'core/bootstrap_form_fields.html' %}

        <input type="submit" class="btn btn-primary" value="{% trans 'Change password' %}" />
    </form>

{% endblock %}
