<div class="overlay" id="project-issues-overlay"
    data-title="Tâches"
    data-placement="bottom auto">

    Les tâches sont générées automatiquement à partir des réponses que vous donnez dans les questionnaires. Sur la page de chaque tâche, vous pouvez voir lesquelles de vos réponses conduisent à l'activation de la tâche. Vous pouvez également modifier le statut de vos tâches à l'aide de l'icône en forme de crayon lorsque vous avez commencé ou terminé une tâche. Avec l'icône de l'avion en papier, vous pouvez envoyer un e-mail et joindre une vue dans le format souhaité, si nécessaire. Au début, l'aperçu des tâches est vide.

    {% include 'overlays/buttons.html'%}
</div>
