<div class="overlay" id="issue-message-overlay"
    data-title="Nachricht"
    data-placement="bottom">

    In den Aufgaben wird oft zur Kontaktaufnahme zu einer anderen Abteilung aufgefordert. Hier finden Sie eine vorgefertigte Nachricht mit den betreffenden Ansprechpartnerinnen bzw. Ansprechpartnern als Adressaten, die Sie hier als E-Mail versenden können.

    {% include 'overlays/buttons.html'%}
</div>
