<div class="overlay" id="project-catalog-overlay"
    data-title="Catalogue"
    data-placement="bottom">

    Avec les bonnes permissions, vous pouvez modifier la sélection du catalogue de questions ici.

    {% include 'overlays/buttons.html'%}
</div>
