# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-21 13:14
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0031_rename_attribute_entity_to_attribute'),
    ]

    operations = [
        migrations.AlterField(
            model_name='question',
            name='attribute',
            field=models.ForeignKey(blank=True, help_text='The attribute this question belongs to.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='domain.Attribute', verbose_name='Attribute'),
        ),
        migrations.AlterField(
            model_name='questionset',
            name='attribute',
            field=models.ForeignKey(blank=True, help_text='The attribute this questionset belongs to.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='domain.Attribute', verbose_name='Attribute'),
        ),
    ]
