<div class="overlay" id="project-views-overlay"
    data-title="Ansichten"
    data-placement="bottom auto">

    Bei den Ansichten handelt es sich um Vorlagen für Formulare/Dokumente. Die Ansichten werden anhand der im Fragenkatalog gegebenen Antworten automatisch ausgefüllt und können anschließend in verschiedenen Formaten exportiert und versendet werden. Zu Beginn sind alle Ansichten leer. Damit die Vorlagen vollständig ausgefüllt werden, müssen alle relevanten Fragen beantwortet werden. Antworten, die in mehreren Vorlagen zur Anwendung kommen, werden automatisch in alle Fragenkataloge und Ansichten übernommen.

    {% include 'overlays/buttons.html'%}
</div>
