<div class="overlay" id="project-catalog-overlay"
    data-title="Catalogo"
    data-placement="bottom">

    Con i permessi giusti, puoi cambiare la selezione del catalogo delle domande qui.

    {% include 'overlays/buttons.html'%}
</div>
