{% load i18n %}

<div class="progress project-progress">
    <div class="progress-bar" role="progressbar" style="width: {$ service.progress.ratio * 100 $}%;">
        <span ng-show="service.progress.ratio > 0.25">
            {% blocktrans trimmed with values='{$ service.progress.values $}' total='{$ service.progress.total $}' %}
                {{ values }} of {{ total }}
            {% endblocktrans %}
        </span>
    </div>
</div>
