# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-03 15:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0026_data_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='question',
            name='optionsets',
        ),
        migrations.RemoveField(
            model_name='question',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='question',
            name='questionentity_ptr',
        ),
        migrations.RemoveField(
            model_name='questionentity',
            name='attribute_entity',
        ),
        migrations.RemoveField(
            model_name='questionentity',
            name='conditions',
        ),
        migrations.RemoveField(
            model_name='questionentity',
            name='subsection',
        ),
        migrations.DeleteModel(
            name='Question',
        ),
        migrations.DeleteModel(
            name='QuestionEntity',
        ),
    ]
