# Generated by Django 2.2.13 on 2020-10-19 11:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('questions', '0053_related_name'),
        ('tasks', '0031_related_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='task',
            name='catalogs',
            field=models.ManyToManyField(blank=True, help_text='The catalogs this task can be used with. An empty list implies that this task can be used with every catalog.', to='questions.Catalog', verbose_name='Catalogs'),
        ),
    ]
